Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["ComplexFocus: Non-paraxial vector beams in \
Mathematica",
 FontSize->
  36]], "Title",ExpressionUUID->"4f97aa06-5237-417d-a3de-abc5fa8e4b58"],

Cell[CellGroupData[{

Cell[TextData[{
 "\[Copyright] Rodrigo Guti\[EAcute]rrez-Cuevas & Emilio Pisanty (2020). \
Licensed under GPL and CC BY-SA.\n",
 StyleBox[" ",
  FontSize->3],
 "\nThis notebook generates the package file for the ComplexFocus package. \
For updates and additional information, go to ",
 ButtonBox["https://github.com/ComplexFocus/ComplexFocus",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://github.com/ComplexFocus/ComplexFocus"], None},
  ButtonNote->"https://github.com/ComplexFocus/ComplexFocus"],
 "."
}], "Text",
 CellGroupingRules->{
  GroupTogetherGrouping, 
   10000.},ExpressionUUID->"6ac175a7-f178-4dfe-9bdc-458722381b12"],

Cell[BoxData[
 RowBox[{"(*", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
   "This", " ", "is", " ", "the", " ", "ComplexFocus", " ", "package"}], ",", 
   " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"\[Copyright]", " ", "Rodrigo", " ", "Guti\[EAcute]rrez"}], "-",
       "Cuevas"}], "&"}], " ", "Emilio", " ", "Pisanty", " ", 
    RowBox[{
     RowBox[{"(", "2020", ")"}], ".", " ", "For"}], " ", "the", " ", 
    "notebook", " ", "that", " ", "generated", " ", "this", " ", "package", 
    " ", "file", " ", "and", " ", "additional", " ", "documentaion"}], ",", 
   " ", 
   RowBox[{
    RowBox[{"see", " ", 
     RowBox[{"https", ":"}]}], "//", 
    RowBox[{
     RowBox[{
      RowBox[{"github", ".", "com"}], "/", "ComplexFocus"}], "/", 
     RowBox[{"ComplexFocus", "."}]}]}]}], "\[IndentingNewLine]", 
  "*)"}]], "Input",
 CellGroupingRules->{GroupTogetherGrouping, 10000.},
 InitializationCell->True,
 CellLabel->"In[1]:=",ExpressionUUID->"82d38177-9df9-4b82-9d60-a29240b5c273"]
}, Closed]],

Cell[CellGroupData[{

Cell["Readme", "Section",
 CellTags->
  "Introduction",ExpressionUUID->"c6192770-807e-4c6d-bd69-7a28378f3924"],

Cell[CellGroupData[{

Cell["Specifications", \
"Subsection",ExpressionUUID->"6d709491-2e85-4a20-92d1-a0c461ce133a"],

Cell[TextData[{
 "The ComplexFocus package implements Complex Focus (CF) vector-beam fields \
as described in the papers\n\n       - Scalar and electromagnetic nonparaxial \
bases composed as superpositions of simple vortex fields with complex foci. \
R. Guti\[EAcute]rrez-Cuevas and M.A. Alonso. ",
 StyleBox[ButtonBox["Optics Express",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1364/OE.25.014856"], None},
  ButtonNote->"https://doi.org/10.1364/OE.25.014856"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1364/OE.25.014856"], None},
  ButtonNote->"https://doi.org/10.1364/OE.25.014856"],
 StyleBox[ButtonBox["25",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1364/OE.25.014856"], None},
  ButtonNote->"https://doi.org/10.1364/OE.25.014856"],
  FontWeight->"Bold"],
 ButtonBox[", pp. 14856-14870 (2017)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1364/OE.25.014856"], None},
  ButtonNote->"https://doi.org/10.1364/OE.25.014856"],
 ".\n       - Optical polarization skyrmionic fields in free space. R. Guti\
\[EAcute]rrez-Cuevas and E. Pisanty. Under review (2020).\n",
 StyleBox[" ",
  FontSize->5]
}], "Text",ExpressionUUID->"573bc852-ad26-4d6f-a777-1b0aaf2d6d36"],

Cell[TextData[{
 "These fields are built on the idea that (i) the multipolar spherical-wave \
functions, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalLambda]", 
      RowBox[{"l", ",", "m"}]], "(", 
     RowBox[{"x", ",", "y", ",", "z"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      SubscriptBox["j", "l"], "(", "r", ")"}], 
     RowBox[{
      SubscriptBox["Y", 
       RowBox[{"l", ",", "m"}]], "(", 
      RowBox[{"\[Theta]", ",", "\[Phi]"}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"35b6ee4d-0ddb-4424-be8a-2d9deab503b8"],
 ", are solutions of the Helmholtz equation, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Del]", "2"], 
       RowBox[{"+", "1"}]}], ")"}], "\[CapitalLambda]"}], "=", "0"}], 
   TraditionalForm]],ExpressionUUID->"3c68540d-f094-4934-8066-3f8ee3596646"],
 ", and (ii) they retain this property if one of the variables is shifted by \
an imaginary-valued offset. This transformation thus keeps them as solutions \
of the wave equation, while at the same time turning them into focused \
beam-like solutions and eventually, in the large-offset limit, into Gaussian \
beam functions. The package thus implements:\n\n - The multipolar functions \
",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalLambda]", 
    RowBox[{"l", ",", "m"}]], TraditionalForm]],ExpressionUUID->
  "dc8d4bc6-85b7-436f-a2af-9ae1a5b7d4a9"],
 ", as Multipole\[CapitalLambda];\n - The vector differential operators ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubsuperscriptBox["V", "r", 
      RowBox[{"(", "E", ")"}]], "(", 
     RowBox[{"v", ",", "f"}], ")"}], "=", 
    RowBox[{"\[Del]", "\[Times]", 
     RowBox[{"(", 
      RowBox[{"\[Del]", "\[Times]", 
       RowBox[{"(", 
        RowBox[{"v", " ", "f"}], ")"}]}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"e8065faa-b640-466f-b0e0-8269c56909ae"],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubsuperscriptBox["V", "r", 
      RowBox[{"(", "M", ")"}]], "(", 
     RowBox[{"v", ",", "f"}], ")"}], "=", 
    RowBox[{
     RowBox[{"-", "i"}], 
     RowBox[{"\[Del]", "\[Times]", 
      RowBox[{"(", 
       RowBox[{"v", " ", "f"}], ")"}]}]}]}], TraditionalForm]],ExpressionUUID->
  "e73f2c45-b94a-4231-bd27-0fb9abaaa635"],
 ", of electric and magnetic type for a vector ",
 Cell[BoxData[
  FormBox["v", TraditionalForm]],ExpressionUUID->
  "30bed1ad-a000-4876-aeee-51714ea559c6"],
 " and a scalar function ",
 Cell[BoxData[
  FormBox["f", TraditionalForm]],ExpressionUUID->
  "80b23dbd-14f8-45c1-b909-a2c60cb95c71"],
 ", as well as the helicity-type operator ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubsuperscriptBox["V", "r", 
      RowBox[{"(", "\[PlusMinus]", ")"}]], "(", "f", ")"}], "=", 
    RowBox[{
     RowBox[{
      SubsuperscriptBox["V", "r", 
       RowBox[{"(", "E", ")"}]], "(", 
      RowBox[{
       SubscriptBox["e", "\[PlusMinus]"], ",", "f"}], ")"}], "\[PlusMinus]", 
     RowBox[{
      SubsuperscriptBox["iV", "r", 
       RowBox[{"(", "M", ")"}]], "(", 
      RowBox[{
       SubscriptBox["e", "\[PlusMinus]"], ",", "f"}], ")"}]}]}], 
   TraditionalForm]],ExpressionUUID->"5ab763cc-51d1-4b7d-bc57-04760bf18fe6"],
 ", which lift the scalar solutions ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[CapitalLambda]", 
    RowBox[{"l", ",", "m"}]], TraditionalForm]],ExpressionUUID->
  "f75f2d37-9348-4235-920c-457c42114540"],
 " into transverse vector solutions; and\n - The complex-focus field \
functions that arise from this process."
}], "Text",ExpressionUUID->"7d22e2a0-3123-4e17-b9ba-33714bd05f5d"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Implementation notes", \
"Subsection",ExpressionUUID->"50c5060d-5941-402a-95ff-4d3813a25538"],

Cell[TextData[{
 "To implement CF fields cleanly, we make heavy use of Mathematica\
\[CloseCurlyQuote]s symbolic differentiator, working in Cartesian \
coordinates.  If done directly, this poses a problem, since the Cartesian \
derivatives of the spherical harmonic ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["Y", 
     RowBox[{"l", ",", "m"}]], "(", 
    RowBox[{"\[Theta]", ",", "\[Phi]"}], ")"}], TraditionalForm]],
  ExpressionUUID->"1c232ba5-5b17-461f-b1b1-0a3a371042ec"],
 " are complex combinations and present significantly singular behaviour at \
the origin \[Dash] a property which is at odds with the fact that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[CapitalLambda]", 
     RowBox[{"l", ",", "m"}]], "(", 
    RowBox[{"x", ",", "y", ",", "z"}], ")"}], TraditionalForm]],
  ExpressionUUID->"a05ea609-d685-4cb7-a8bc-d4992afec09e"],
 " is an entire function of all three Cartesian coordinates.\n\nTo solve this \
problem, we re-factor the fundamental multipole functions as ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[CapitalLambda]", 
      RowBox[{"l", ",", "m"}]], "(", 
     RowBox[{"x", ",", "y", ",", "z"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      RowBox[{
       SubscriptBox["j", "l"], "(", "r", ")"}], 
      RowBox[{
       SubscriptBox["Y", 
        RowBox[{"l", ",", "m"}]], "(", 
       RowBox[{"\[Theta]", ",", "\[Phi]"}], ")"}]}], "=", 
     RowBox[{
      RowBox[{
       SubscriptBox["aj", "l"], "(", "r", ")"}], 
      RowBox[{
       SubscriptBox["S", 
        RowBox[{"l", ",", "m"}]], "(", 
       RowBox[{"x", ",", "y", ",", "z"}], ")"}]}]}]}], TraditionalForm]],
  ExpressionUUID->"f6203cd3-d986-43d1-b1ba-e861884c56f2"],
 ", where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["S", 
      RowBox[{"l", ",", "m"}]], "(", 
     RowBox[{"x", ",", "y", ",", "z"}], ")"}], "=", 
    RowBox[{
     SuperscriptBox["r", "l"], 
     RowBox[{
      SubscriptBox["Y", 
       RowBox[{"l", ",", "m"}]], "(", 
      RowBox[{"\[Theta]", ",", "\[Phi]"}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"b5dc6321-230c-447f-9f71-6fbe26cf0982"],
 " are solid harmonics (and therefore homogeneous polynomials in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", ",", "y", ",", "z"}], TraditionalForm]],ExpressionUUID->
  "e9a81f96-733a-45c1-bb36-05b82e884192"],
 ") and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["aj", "l"], "(", 
     RowBox[{"x", ",", "y", ",", "z"}], ")"}], "=", 
    RowBox[{
     RowBox[{
      FractionBox["1", 
       SuperscriptBox["r", "l"]], 
      RowBox[{
       SubscriptBox["j", "l"], "(", "r", ")"}]}], "=", 
     RowBox[{
      RowBox[{
       FractionBox["1", 
        RowBox[{
         RowBox[{"(", 
          RowBox[{
           RowBox[{"2", "l"}], "+", "1"}], ")"}], "!!"}]], "-", 
       FractionBox[
        RowBox[{
         SuperscriptBox["x", "2"], "+", 
         SuperscriptBox["y", "2"], "+", 
         SuperscriptBox["z", "2"]}], 
        RowBox[{"2", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{
            RowBox[{"2", "l"}], "+", "3"}], ")"}], "!!"}]}]], "+"}], 
      "..."}]}]}], TraditionalForm]],ExpressionUUID->
  "07a11cd8-a0c0-41ab-8204-f31015aca652"],
 ", implemented as AnalyticalBesselJ, is the spherical Bessel function with \
its asymptotic behaviour at the origin removed (thus making it an even Taylor \
series in powers of ",
 Cell[BoxData[
  FormBox[
   RowBox[{"x", ",", "y", ",", "z"}], TraditionalForm]],ExpressionUUID->
  "2a8cf9f9-ce74-4c6c-baf9-784317d6ae2a"],
 ", without any square roots coming from ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "=", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"], "+", 
      SuperscriptBox["z", "2"]}]]}], TraditionalForm]],ExpressionUUID->
  "174a2095-c13e-42cf-bfda-25a7ab5c0106"],
 "). The Cartesian derivatives of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["aj", "l"], "(", 
    RowBox[{"x", ",", "y", ",", "z"}], ")"}], TraditionalForm]],
  ExpressionUUID->"bf211839-3c39-4a93-ac41-8463e82c3cfa"],
 " are then coded explicitly using the recursion relation ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FractionBox["d", 
      RowBox[{"d", " ", "r"}]], 
     RowBox[{"(", 
      RowBox[{
       FractionBox["1", 
        SuperscriptBox["r", "l"]], 
       RowBox[{
        SubscriptBox["j", "l"], "(", "r", ")"}]}], ")"}]}], "=", " ", 
    RowBox[{
     RowBox[{"-", 
      FractionBox["1", 
       SuperscriptBox["r", "l"]]}], 
     RowBox[{
      SubscriptBox["j", 
       RowBox[{"l", "+", "1"}]], "(", "r", ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"3d356339-b269-4a4a-80f6-2ca8b235d519"],
 " (",
 ButtonBox["DLMF 10.51.3",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://dlmf.nist.gov/10.51#E3"], None},
  ButtonNote->"https://dlmf.nist.gov/10.51#E3"],
 ") and the chain rule ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"\[PartialD]", "r"}], 
     RowBox[{"\[PartialD]", "x"}]], "=", 
    FractionBox["x", "r"]}], TraditionalForm]],ExpressionUUID->
  "7915d682-7fa3-43b5-93f2-7e6f3daac32a"],
 " to get ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     FractionBox["\[PartialD]", 
      RowBox[{"\[PartialD]", "x"}]], 
     RowBox[{
      SubscriptBox["aj", "l"], "(", 
      RowBox[{"x", ",", "y", ",", "z"}], ")"}]}], "=", " ", 
    RowBox[{
     RowBox[{"-", "x"}], " ", 
     RowBox[{
      SubscriptBox["aj", 
       RowBox[{"l", "+", "1"}]], "(", 
      RowBox[{"x", ",", "y", ",", "z"}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"7b9789a3-331c-4056-9f02-3e522bced90c"],
 " (and equivalently for ",
 Cell[BoxData[
  FormBox["y", TraditionalForm]],ExpressionUUID->
  "38408454-da55-4780-8fdf-187795307644"],
 " and ",
 Cell[BoxData[
  FormBox["z", TraditionalForm]],ExpressionUUID->
  "0555665e-6f49-4292-af07-88f6a28e26e3"],
 ")."
}], "Text",ExpressionUUID->"12d33346-23ac-46ec-997a-6ffe2743e2a5"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Package admin", \
"Section",ExpressionUUID->"63ce1fac-976b-4ffb-9096-45068b912d68"],

Cell[CellGroupData[{

Cell["Initialization", \
"Subsection",ExpressionUUID->"5aeda15b-76fe-4aed-a4a6-75764c3d3231"],

Cell[BoxData[
 RowBox[{
  RowBox[{"BeginPackage", "[", "\"\<ComplexFocus`\>\"", "]"}], ";"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[2]:=",ExpressionUUID->"d8194a12-20ba-4527-9da4-5c21f77858c8"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Package admin", \
"Subsection",ExpressionUUID->"b342e1b8-f293-4421-bf51-03eecc098c29"],

Cell[CellGroupData[{

Cell["Version managing", "Subsubsection",
 CellTags->
  "version-section",ExpressionUUID->"4a58faea-5e89-4a18-8638-f58dbf15ff2e"],

Cell["\<\
The variable $ComplexFocusVersion gives the version of the ComplexFocus \
package currently loaded as well as its timestamp\
\>", "Text",ExpressionUUID->"3cc4e9c7-4560-4484-b6a1-3feb4291ed7c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"$ComplexFocusVersion", "::", "usage"}], "=", 
   "\"\<$ComplexFocusVersion prints the current version of the ComplexFocus \
package in use and its timestamp.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"$ComplexFocusTimestamp", "::", "usage"}], "=", 
   "\"\<$ComplexFocusTimestamp prints the timestamp of the current version of \
the ComplexFocus package.\>\""}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[3]:=",ExpressionUUID->"aa97ee0f-f35a-441d-9482-ce45b1a816f6"],

Cell["\<\
The timestamp is updated every time this notebook is saved, via an \
appropriate notebook option which is set by the code below.\
\>", "Text",ExpressionUUID->"887427dc-d969-4eef-9ca3-6df9cab14874"],

Cell[BoxData[
 RowBox[{
  RowBox[{"SetOptions", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"EvaluationNotebook", "[", "]"}], ",", "\[IndentingNewLine]", 
    RowBox[{"NotebookEventActions", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\"\<MenuCommand\>\"", ",", "\"\<Save\>\""}], "}"}], 
        "\[RuleDelayed]", 
        RowBox[{"(", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"NotebookWrite", "[", "\[IndentingNewLine]", 
           RowBox[{
            RowBox[{
             RowBox[{"Cells", "[", 
              RowBox[{"CellTags", "\[Rule]", "\"\<version-timestamp\>\""}], 
              "]"}], "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
            ",", "\[IndentingNewLine]", 
            RowBox[{"Cell", "[", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"BoxData", "[", 
               RowBox[{"RowBox", "[", 
                RowBox[{"{", 
                 RowBox[{"\"\<$ComplexFocusTimestamp=\\\"\>\"", "<>", 
                  RowBox[{"DateString", "[", "]"}], "<>", 
                  "\"\<\\\";\\nEnd[];\>\""}], "}"}], "]"}], "]"}], 
              "\[IndentingNewLine]", ",", "\"\<Input\>\"", ",", 
              RowBox[{"InitializationCell", "\[Rule]", "True"}], ",", 
              RowBox[{"CellTags", "\[Rule]", "\"\<version-timestamp\>\""}]}], 
             "\[IndentingNewLine]", "]"}], ",", "None", ",", 
            RowBox[{"AutoScroll", "\[Rule]", "False"}]}], "]"}], ";", 
          "\[IndentingNewLine]", 
          RowBox[{"NotebookSave", "[", "]"}]}], "\[IndentingNewLine]", 
         ")"}]}], ",", 
       RowBox[{"PassEventsDown", "\[Rule]", "True"}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}], 
  ";"}]], "Input",ExpressionUUID->"9fc2d5fa-1617-4717-8d93-fc3b81379664"],

Cell["To reset this behaviour to normal, evaluate the cell below", \
"Text",ExpressionUUID->"bc795509-3913-49b6-84f3-de50f36f2b1a"],

Cell[BoxData[
 RowBox[{"SetOptions", "[", 
  RowBox[{
   RowBox[{"EvaluationNotebook", "[", "]"}], ",", 
   RowBox[{"NotebookEventActions", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"{", 
        RowBox[{"\"\<MenuCommand\>\"", ",", "\"\<Save\>\""}], "}"}], 
       "\[RuleDelayed]", 
       RowBox[{"(", 
        RowBox[{"NotebookSave", "[", "]"}], ")"}]}], ",", 
      RowBox[{"PassEventsDown", "\[Rule]", "True"}]}], "}"}]}]}], 
  "]"}]], "Input",ExpressionUUID->"45760a97-ec43-42f5-a401-6d3b7f33f832"]
}, Closed]],

Cell[CellGroupData[{

Cell["Version number and timestamp", \
"Subsubsection",ExpressionUUID->"2ac2d3ad-8207-436c-afb8-bc0ae16d4c35"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"$ComplexFocusVersion", ":=", 
   RowBox[{"\"\<ComplexFocus v1.0, \>\"", "<>", "$ComplexFocusTimestamp"}]}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[5]:=",ExpressionUUID->"90617182-59d4-4545-b4c7-e01a2308359e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"$ComplexFocusTimestamp", "=", "\"\<Tue 1 Dec 2020 22:39:54\>\""}], 
  ";"}], "\n", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellTags->
  "version-timestamp",ExpressionUUID->"caa2493d-0f25-4780-b00e-c63522af6c2e"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Directory", \
"Subsubsection",ExpressionUUID->"d265a8f6-abd3-4556-b1e7-2a394098c33f"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"$ComplexFocusDirectory", "::", "usage"}], "=", 
   "\"\<$ComplexFocusDirectory is the directory where the current \
ComplexFocus package instance is located.\>\""}], ";"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[9]:=",ExpressionUUID->"c87f6883-8e5e-4a34-a1b9-2f3cdfa24230"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"With", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"softLinkTestString", "=", 
      RowBox[{"StringSplit", "[", 
       RowBox[{
        RowBox[{"StringJoin", "[", 
         RowBox[{"ReadList", "[", 
          RowBox[{
           RowBox[{"\"\<! ls -la \>\"", "<>", 
            RowBox[{"StringReplace", "[", 
             RowBox[{"$InputFileName", ",", 
              RowBox[{"{", 
               RowBox[{"\"\< \>\"", "\[Rule]", "\"\<\\\\ \>\""}], "}"}]}], 
             "]"}]}], ",", "String"}], "]"}], "]"}], ",", "\"\< -> \>\""}], 
       "]"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"If", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Length", "[", "softLinkTestString", "]"}], ">", "1"}], ",", 
      RowBox[{"(*", 
       RowBox[{
       "Testing", " ", "in", " ", "case", " ", "$InputFileName", " ", "is", 
        " ", "a", " ", "soft", " ", "link", " ", "to", " ", "the", " ", 
        "actual", " ", 
        RowBox[{"directory", "."}]}], "*)"}], "\[IndentingNewLine]", 
      RowBox[{"$ComplexFocusDirectory", "=", 
       RowBox[{"StringReplace", "[", 
        RowBox[{
         RowBox[{"DirectoryName", "[", 
          RowBox[{
          "softLinkTestString", "\[LeftDoubleBracket]", "2", 
           "\[RightDoubleBracket]"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"\"\< \>\"", "\[Rule]", "\"\<\\\\ \>\""}], "}"}]}], "]"}]}],
       ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"$ComplexFocusDirectory", "=", 
        RowBox[{"StringReplace", "[", 
         RowBox[{
          RowBox[{"DirectoryName", "[", "$InputFileName", "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"\"\< \>\"", "\[Rule]", "\"\<\\\\ \>\""}], "}"}]}], 
         "]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}]}], "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[10]:=",ExpressionUUID->"f4003c50-c4bf-43a7-96de-6f1292ddff7e"]
}, Closed]],

Cell[CellGroupData[{

Cell["Git commit hash and message", \
"Subsubsection",ExpressionUUID->"b01571eb-22a0-4ae9-bcdf-68217bd8bd00"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"$ComplexFocusCommit", "::", "usage"}], "=", 
   "\"\<$ComplexFocusCommit returns the git commit log at the location of the \
ComplexFocus package if there is one.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"$ComplexFocusCommit", "::", "OS"}], "=", 
   "\"\<$ComplexFocusCommit has only been tested on Linux.\>\""}], 
  ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[13]:=",ExpressionUUID->"fce25619-8923-4995-9cae-ebb712b0cd01"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"$ComplexFocusCommit", ":=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"$OperatingSystem", "\[NotEqual]", "\"\<Unix\>\""}], ",", 
       RowBox[{"Message", "[", 
        RowBox[{"$ComplexFocusCommit", "::", "OS"}], "]"}]}], "]"}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"StringJoin", "[", 
      RowBox[{"Riffle", "[", 
       RowBox[{
        RowBox[{"ReadList", "[", 
         RowBox[{
          RowBox[{
          "\"\<!cd \>\"", "<>", "$ComplexFocusDirectory", "<>", 
           "\"\< && git log -1\>\""}], ",", "String"}], "]"}], ",", 
        RowBox[{"{", "\"\<\\n\>\"", "}"}]}], "]"}], "]"}]}], ")"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[15]:=",ExpressionUUID->"56b69d2c-3f13-4848-bcc7-6db05f85bf58"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Package code", \
"Section",ExpressionUUID->"3844a50e-ebb3-4a6c-8d34-f82b94b045bd"],

Cell[CellGroupData[{

Cell["SolidHarmonicS", \
"Subsection",ExpressionUUID->"ce066b21-33f3-4900-bb2d-ab254654ae24"],

Cell[TextData[{
 "This function implements the solid harmonic ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["S", 
      RowBox[{"l", ",", "m"}]], "(", 
     StyleBox["r",
      FontWeight->"Bold"], ")"}], "=", 
    RowBox[{
     SuperscriptBox["r", "l"], 
     RowBox[{
      SubscriptBox["Y", 
       RowBox[{"l", ",", "m"}]], "(", 
      RowBox[{"\[Theta]", ",", "\[Phi]"}], ")"}]}]}], TraditionalForm]],
  ExpressionUUID->"ff1a7c97-fd16-4e84-a045-0d295246ab11"],
 ", which is a homogeneous polynomial of degree ",
 Cell[BoxData[
  FormBox["l", TraditionalForm]],ExpressionUUID->
  "1a7df1cc-f549-49c6-a885-447a0d80d3ac"],
 ", and lends itself much better to symbolic differentiation than explicit \
spherical harmonics.\n\nCode provided by J.M. at \
http://mathematica.stackexchange.com/a/124336/1000 under the WTFPL."
}], "Text",ExpressionUUID->"5ffc79c6-f6d8-4512-8151-b93a8d9cc9b5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"SolidHarmonicS", "::", "usage"}], "=", 
   "\"\<SolidHarmonicS[l,m,x,y,z] calculates the solid harmonic \
\!\(\*SubscriptBox[\(S\), \(lm\)]\)(x,y,z)=\!\(\*SuperscriptBox[\(r\), \(l\)]\
\)\!\(\*SubscriptBox[\(Y\), \(lm\)]\)(x,y,z).\n\nSolidHarmonicS[l,m,{x,y,z}] \
does the same.\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SolidHarmonicS", "[", 
    RowBox[{
    "\[Lambda]_Integer", ",", "\[Mu]_Integer", ",", "x_", ",", "y_", ",", 
     "z_"}], "]"}], "/;", 
   RowBox[{"\[Lambda]", "\[GreaterEqual]", 
    RowBox[{"Abs", "[", "\[Mu]", "]"}]}]}], ":=", 
  RowBox[{
   RowBox[{"Sqrt", "[", 
    FractionBox[
     RowBox[{
      RowBox[{"2", " ", "\[Lambda]"}], "+", "1"}], 
     RowBox[{"4", " ", "\[Pi]"}]], "]"}], " ", 
   RowBox[{"Sqrt", "[", 
    FractionBox[
     RowBox[{"Gamma", "[", 
      RowBox[{"\[Lambda]", "-", 
       RowBox[{"Abs", "[", "\[Mu]", "]"}], "+", "1"}], "]"}], 
     RowBox[{"Gamma", "[", 
      RowBox[{"\[Lambda]", "+", 
       RowBox[{"Abs", "[", "\[Mu]", "]"}], "+", "1"}], "]"}]], "]"}], " ", 
   SuperscriptBox["2", 
    RowBox[{"-", "\[Lambda]"}]], " ", 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"\[Mu]", "-", 
       RowBox[{"Abs", "[", "\[Mu]", "]"}]}], ")"}], "/", "2"}]], "\[Times]", 
   "\[IndentingNewLine]", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Rationalize", "[", "\[Mu]", "]"}], "\[Equal]", "0"}], ",", "1",
      ",", 
     SuperscriptBox[
      RowBox[{"(", 
       RowBox[{"x", "+", 
        RowBox[{
         RowBox[{"Sign", "[", "\[Mu]", "]"}], "\[ImaginaryI]", " ", "y"}]}], 
       ")"}], 
      RowBox[{"Abs", "[", "\[Mu]", "]"}]]}], "]"}], "\[Times]", 
   "\[IndentingNewLine]", 
   RowBox[{"Sum", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        RowBox[{"-", "1"}], ")"}], 
       RowBox[{"\[Mu]", "+", "k"}]], " ", 
      RowBox[{"Binomial", "[", 
       RowBox[{"\[Lambda]", ",", "k"}], "]"}], " ", 
      RowBox[{"Binomial", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"2", " ", "\[Lambda]"}], "-", 
         RowBox[{"2", " ", "k"}]}], ",", "\[Lambda]"}], "]"}], " ", 
      RowBox[{"Pochhammer", "[", 
       RowBox[{
        RowBox[{"\[Lambda]", "-", 
         RowBox[{"Abs", "[", "\[Mu]", "]"}], "-", 
         RowBox[{"2", " ", "k"}], "+", "1"}], ",", 
        RowBox[{"Abs", "[", "\[Mu]", "]"}]}], "]"}], " ", "\[Times]", 
      "\[IndentingNewLine]", 
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"TrueQ", "[", 
         RowBox[{
          RowBox[{"Pochhammer", "[", 
           RowBox[{
            RowBox[{"\[Lambda]", "-", 
             RowBox[{"Abs", "[", "\[Mu]", "]"}], "-", 
             RowBox[{"2", " ", "k"}], "+", "1"}], ",", 
            RowBox[{"Abs", "[", "\[Mu]", "]"}]}], "]"}], "\[Equal]", "0"}], 
         "]"}], ",", "1", ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Rationalize", "[", "k", "]"}], "\[Equal]", "0"}], ",", 
           "1", ",", 
           SuperscriptBox[
            RowBox[{"(", 
             RowBox[{
              SuperscriptBox["x", "2"], "+", 
              SuperscriptBox["y", "2"], "+", 
              SuperscriptBox["z", "2"]}], ")"}], "k"]}], "]"}], 
         RowBox[{"If", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Rationalize", "[", 
             RowBox[{"\[Lambda]", "-", 
              RowBox[{"Abs", "[", "\[Mu]", "]"}], "-", 
              RowBox[{"2", " ", "k"}]}], "]"}], "\[Equal]", "0"}], ",", "1", 
           ",", 
           SuperscriptBox["z", 
            RowBox[{"\[Lambda]", "-", 
             RowBox[{"Abs", "[", "\[Mu]", "]"}], "-", 
             RowBox[{"2", " ", "k"}]}]]}], "]"}]}]}], "\[IndentingNewLine]", 
       "]"}]}], "\[IndentingNewLine]", ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "0", ",", 
       RowBox[{"Quotient", "[", 
        RowBox[{"\[Lambda]", ",", "2"}], "]"}]}], "}"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SolidHarmonicS", "[", 
    RowBox[{"\[Lambda]_Integer", ",", "\[Mu]_Integer", ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}]}], "]"}], "/;", 
   RowBox[{"\[Lambda]", "\[GreaterEqual]", 
    RowBox[{"Abs", "[", "\[Mu]", "]"}]}]}], ":=", 
  RowBox[{"SolidHarmonicS", "[", 
   RowBox[{"\[Lambda]", ",", "\[Mu]", ",", "x", ",", "y", ",", "z"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[18]:=",ExpressionUUID->"53f36aab-68fb-4989-8c67-cfe0a0e9f7dd"]
}, Closed]],

Cell[CellGroupData[{

Cell["AnalyticalBesselJ", \
"Subsection",ExpressionUUID->"9b9e0ef1-5a30-4169-a872-3cfb1a95a411"],

Cell["\<\
Define the analytical Bessel functions that go with the solid harmonics, as \
well as their differentiation rules.\
\>", "Text",ExpressionUUID->"76a6b390-5a4e-4a6a-95ac-68d711efaa97"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"AnalyticalBesselJ", "::", "usage"}], "=", 
    "\"\<AnalyticalBesselJ[m,{x,y,z}] gives the analytical form of the \
spherical Bessel function, \!\(\*SubscriptBox[\(aj\), \
\(m\)]\)(r)=\!\(\*SubscriptBox[\(j\), \(m\)]\)(r)/\!\(\*SuperscriptBox[\(r\), \
\(m\)]\).\>\""}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"AnalyticalBesselJ", "[", 
   RowBox[{"m_", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"x_", "?", "NumericQ"}], ",", 
      RowBox[{"y_", "?", "NumericQ"}], ",", 
      RowBox[{"z_", "?", "NumericQ"}]}], "}"}]}], "]"}], ":=", 
  FractionBox[
   RowBox[{"SphericalBesselJ", "[", 
    RowBox[{
     RowBox[{"Abs", "[", "m", "]"}], ",", 
     SqrtBox[
      RowBox[{
       SuperscriptBox["x", "2"], "+", 
       SuperscriptBox["y", "2"], "+", 
       SuperscriptBox["z", "2"]}]]}], "]"}], 
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"], "+", 
      SuperscriptBox["z", "2"]}], ")"}], 
    RowBox[{
     RowBox[{"Abs", "[", "m", "]"}], "/", "2"}]]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"AnalyticalBesselJ", "[", 
    RowBox[{"m_", ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"x_", "?", "NumericQ"}], ",", 
        RowBox[{"y_", "?", "NumericQ"}], ",", 
        RowBox[{"z_", "?", "NumericQ"}]}], "}"}], "/;", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], "\[Equal]", "0"}], "||", 
        RowBox[{
         RowBox[{
          SuperscriptBox["x", "2"], "+", 
          SuperscriptBox["y", "2"], "+", 
          SuperscriptBox["z", "2"]}], "\[Equal]", "0."}]}], ")"}]}]}], "]"}], 
   ":=", 
   FractionBox["1", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "m"}], "+", "1"}], ")"}], "!!"}]]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Derivative", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "0", ",", "0"}], "}"}]}], "]"}], "[", 
    "AnalyticalBesselJ", "]"}], "[", 
   RowBox[{"m_", ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], "x", " ", 
   RowBox[{"AnalyticalBesselJ", "[", 
    RowBox[{
     RowBox[{"m", "+", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Derivative", "[", 
     RowBox[{"0", ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "0"}], "}"}]}], "]"}], "[", 
    "AnalyticalBesselJ", "]"}], "[", 
   RowBox[{"m_", ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{"-", "1"}], ")"}], "y", " ", 
   RowBox[{"AnalyticalBesselJ", "[", 
    RowBox[{
     RowBox[{"m", "+", "1"}], ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Derivative", "[", 
      RowBox[{"0", ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "]"}], "[", 
     "AnalyticalBesselJ", "]"}], "[", 
    RowBox[{"m_", ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}]}], "]"}], ":=", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"-", "1"}], ")"}], "z", " ", 
    RowBox[{"AnalyticalBesselJ", "[", 
     RowBox[{
      RowBox[{"m", "+", "1"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[23]:=",ExpressionUUID->"2595089e-5a75-43d8-87be-ae8274f74fca"]
}, Closed]],

Cell[CellGroupData[{

Cell["Multipole\[CapitalLambda]", \
"Subsection",ExpressionUUID->"4f41a858-1216-4f69-a0a9-6de6b815f17c"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Multipole\[CapitalLambda]", "::", "usage"}], "=", 
    "\"\<Multipole\[CapitalLambda][l,m,{x,y,z}] calculates the multipole \
function \!\(\*SubscriptBox[\(\[CapitalLambda]\), \(l, \
m\)]\)(x,y,z)=4\!\(\*SuperscriptBox[\(\[Pi]i\), \
\(l\)]\)\!\(\*SubscriptBox[\(j\), \(l\)]\)(r)\!\(\*SubscriptBox[\(Y\), \
\(lm\)]\)(\[Theta],\[Phi])=4\!\(\*SuperscriptBox[\(\[Pi]i\), \
\(l\)]\)\!\(\*SubscriptBox[\(aj\), \(l\)]\)(r)\!\(\*SubscriptBox[\(S\), \
\(lm\)]\)(x,y,z).\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Multipole\[CapitalLambda]", "[", 
    RowBox[{"l_", ",", "m_", ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}]}], "]"}], ":=", 
   RowBox[{"4", "\[Pi]", " ", 
    SuperscriptBox["\[ImaginaryI]", "l"], 
    RowBox[{"AnalyticalBesselJ", "[", 
     RowBox[{"l", ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], 
    RowBox[{"SolidHarmonicS", "[", 
     RowBox[{"l", ",", "m", ",", "x", ",", "y", ",", "z"}], "]"}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[31]:=",ExpressionUUID->"97bacd18-5916-4ffd-9528-2285cc18b967"]
}, Closed]],

Cell[CellGroupData[{

Cell["Polarization handling", \
"Subsection",ExpressionUUID->"6f604981-3a3d-458b-a5b5-59f5e1b8d14d"],

Cell[CellGroupData[{

Cell["Unit vectors", \
"Subsubsection",ExpressionUUID->"f8ded737-c90a-443b-8e8e-69faa92ff9a0"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"UnitE", "::", "usage"}], "=", 
   "\"\<UnitE[s] gives the unit vectors \!\(\*SubscriptBox[\(e\), \(s\)]\) \
for s=-1,0,1, equal to (1,-i,0)/\!\(\*SqrtBox[\(2\)]\), (0,0,1) and \
(1,i,0)/\!\(\*SqrtBox[\(2\)]\), respectively.\>\""}], ";", 
  RowBox[{
   RowBox[{"UnitU", "::", "usage"}], "=", 
   "\"\<UnitU[\[Theta],\[Phi]] gives the radial unit vector \
(sin(\[Theta])cos(\[Phi]),sin(\[Theta])sin(\[Phi]),cos(\[Theta])) at \
spherical polar coordinates (\[Theta],\[Phi]).\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Unit\[Theta]", "::", "usage"}], "=", 
   "\"\<Unit\[Theta][\[Theta],\[Phi]] gives the polar unit vector (cos(\
\[Theta])cos(\[Phi]),cos(\[Theta])sin(\[Phi]),-sin(\[Theta])) at spherical \
polar coordinates (\[Theta],\[Phi]).\>\""}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Unit\[Phi]", "::", "usage"}], "=", 
    "\"\<Unit\[Phi][\[Theta],\[Phi]] gives the azimuthal unit vector (-sin(\
\[Phi]),cos(\[Phi]),0) at spherical polar coordinates \
(\[Theta],\[Phi]).\>\""}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UnitE", "[", 
   RowBox[{"s", ":", 
    RowBox[{"(", 
     RowBox[{"1", "|", 
      RowBox[{"-", "1"}]}], ")"}]}], "]"}], ":=", 
  RowBox[{
   FractionBox["1", 
    SqrtBox["2"]], 
   RowBox[{"{", 
    RowBox[{"1", ",", 
     RowBox[{"s", " ", "\[ImaginaryI]"}], ",", "0"}], 
    "}"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UnitE", "[", "0", "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UnitU", "[", 
    RowBox[{"\[Theta]_", ",", "\[Phi]_"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"Cos", "[", "\[Phi]", "]"}], 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
     RowBox[{
      RowBox[{"Sin", "[", "\[Phi]", "]"}], 
      RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
     RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "}"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Unit\[Theta]", "[", 
   RowBox[{"\[Theta]_", ",", "\[Phi]_"}], "]"}], ":=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{"Cos", "[", "\[Phi]", "]"}], 
     RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
    RowBox[{
     RowBox[{"Sin", "[", "\[Phi]", "]"}], 
     RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ",", 
    RowBox[{"-", 
     RowBox[{"Sin", "[", "\[Theta]", "]"}]}]}], 
   "}"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Unit\[Phi]", "[", 
    RowBox[{"\[Theta]_", ",", "\[Phi]_"}], "]"}], ":=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", 
      RowBox[{"Sin", "[", "\[Phi]", "]"}]}], ",", 
     RowBox[{"Cos", "[", "\[Phi]", "]"}], ",", "0"}], "}"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[35]:=",ExpressionUUID->"4c3f4462-b199-44ef-ba89-fc0bf84bfd63"]
}, Closed]],

Cell[CellGroupData[{

Cell["PolarizationV variants (real space)", \
"Subsubsection",ExpressionUUID->"d9b6c49e-fbb5-4b81-afb7-fe21aa6b5db5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"PolarizationVElectric", "::", "usage"}], "=", 
   "\"\<PolarizationVElectric[v,f[x,y,z],{x,y,z}] gives the electric-type \
polarization operator \!\(\*SubsuperscriptBox[\(V\), \(v\), \((E)\)]\)f=-\
\[Del]\[Times](\[Del]\[Times](v f)) for a vector v and a scalar function f.\n\
PolarizationVElectric[v,f] gives the functional form of \
\!\(\*SubsuperscriptBox[\(V\), \(v\), \((E)\)]\)f. The vector v can be a \
fixed object or an explicit Function object.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PolarizationVMagnetic", "::", "usage"}], "=", 
   "\"\<PolarizationVMagnetic[v,f[x,y,z],{x,y,z}] gives the magnetic-type \
polarization operator \!\(\*SubsuperscriptBox[\(V\), \(v\), \((M)\)]\)f=-i\
\[Del]\[Times](v f) for a vector v and a scalar function f.\n\
PolarizationVMagnetic[v,f] gives the functional form of \
\!\(\*SubsuperscriptBox[\(V\), \(v\), \((M)\)]\)f. The vector v can be a \
fixed object or an explicit Function object.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"PolarizationVHelicity", "::", "usage"}], "=", 
    "\"\<PolarizationVHelicity[\[Sigma],f[x,y,z],{x,y,z}] gives the \
helicity-type polarization operator \!\(\*SuperscriptBox[\(V\), \((\
\[PlusMinus])\)]\)f=\!\(\*SubsuperscriptBox[\(V\), SubscriptBox[\(e\), \(\
\[PlusMinus]\)], \((E)\)]\)f\[PlusMinus]\!\(\*SubsuperscriptBox[\(iV\), \
SubscriptBox[\(e\), \(\[PlusMinus]\)], \((M)\)]\)f for a helicity \[Sigma]=\
\[PlusMinus]1 and a scalar function f.\nPolarizationVHelicity[\[Sigma],f] \
gives the functional form of \!\(\*SuperscriptBox[\(V\), \
\((\[PlusMinus])\)]\)f.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PolarizationVElectric", "[", 
   RowBox[{"vector_", ",", "scalarFunction_", ",", "variables_"}], "]"}], ":=", 
  RowBox[{"-", 
   RowBox[{"Curl", "[", 
    RowBox[{
     RowBox[{"Curl", "[", 
      RowBox[{
       RowBox[{"Times", "[", 
        RowBox[{"vector", ",", "scalarFunction"}], "]"}], ",", "variables"}], 
      "]"}], ",", "variables"}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PolarizationVMagnetic", "[", 
   RowBox[{"vector_", ",", "scalarFunction_", ",", "variables_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"-", "\[ImaginaryI]"}], " ", 
   RowBox[{"Curl", "[", 
    RowBox[{
     RowBox[{"Times", "[", 
      RowBox[{"vector", ",", "scalarFunction"}], "]"}], ",", "variables"}], 
    "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PolarizationVHelicity", "[", 
    RowBox[{
     RowBox[{"s", ":", 
      RowBox[{"(", 
       RowBox[{"1", "|", 
        RowBox[{"-", "1"}]}], ")"}]}], ",", "scalarFunction_", ",", 
     "variables_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"PolarizationVElectric", "[", 
     RowBox[{
      RowBox[{"UnitE", "[", "s", "]"}], ",", "scalarFunction", ",", 
      "variables"}], "]"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     RowBox[{"PolarizationVMagnetic", "[", 
      RowBox[{
       RowBox[{"UnitE", "[", "s", "]"}], ",", "scalarFunction", ",", 
       "variables"}], "]"}]}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PolarizationVElectric", "[", 
   RowBox[{"vector_", ",", "scalarFunction_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
      RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
       RowBox[{"PolarizationVElectric", "[", 
        RowBox[{"vector", ",", 
         RowBox[{"scalarFunction", "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], 
       "\[IndentingNewLine]", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PolarizationVElectric", "[", 
    RowBox[{"vector_Function", ",", "scalarFunction_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
       RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
        RowBox[{"PolarizationVElectric", "[", 
         RowBox[{
          RowBox[{"vector", "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
          RowBox[{"scalarFunction", "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], 
        "\[IndentingNewLine]", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PolarizationVMagnetic", "[", 
   RowBox[{"vector_", ",", "scalarFunction_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
      RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
       RowBox[{"PolarizationVMagnetic", "[", 
        RowBox[{"vector", ",", 
         RowBox[{"scalarFunction", "[", 
          RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], 
       "\[IndentingNewLine]", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PolarizationVMagnetic", "[", 
    RowBox[{"vector_Function", ",", "scalarFunction_"}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
       RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
        RowBox[{"PolarizationVMagnetic", "[", 
         RowBox[{
          RowBox[{"vector", "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
          RowBox[{"scalarFunction", "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], 
        "\[IndentingNewLine]", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PolarizationVHelicity", "[", 
    RowBox[{
     RowBox[{"s", ":", 
      RowBox[{"(", 
       RowBox[{"1", "|", 
        RowBox[{"-", "1"}]}], ")"}]}], ",", "scalarFunction_"}], "]"}], ":=", 
   
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Function", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", 
       RowBox[{"Evaluate", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"PolarizationVElectric", "[", 
          RowBox[{
           RowBox[{"UnitE", "[", "s", "]"}], ",", 
           RowBox[{"scalarFunction", "[", 
            RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", "s", " ", 
          RowBox[{"PolarizationVMagnetic", "[", 
           RowBox[{
            RowBox[{"UnitE", "[", "s", "]"}], ",", 
            RowBox[{"scalarFunction", "[", 
             RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}]}]}], 
        "\[IndentingNewLine]", "]"}]}], "]"}]}], "\[IndentingNewLine]", 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[45]:=",ExpressionUUID->"80eb1906-037d-4820-a34f-a0b6806a2832"]
}, Closed]],

Cell[CellGroupData[{

Cell["Polarization\[ScriptCapitalV] variants (PWS space)", \
"Subsubsection",ExpressionUUID->"3f0b3bb1-9aff-4386-9251-f0a28c776d11"],

Cell[TextData[{
 "The symbol ",
 Cell[BoxData[
  FormBox["\[ScriptCapitalV]", TraditionalForm]],ExpressionUUID->
  "f6b7ada3-885e-4b73-b4b9-1e6134f13d9a"],
 " can be typeset using the combination \[AliasIndicator]scV\[AliasIndicator]."
}], "Text",ExpressionUUID->"d02e48a3-df2b-485c-8e84-851cb54d9980"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Polarization\[ScriptCapitalV]Electric", "::", "usage"}], "=", 
    "\"\<Polarization\[ScriptCapitalV]Electric[v,u] gives the electric-type \
polarization vector \!\(\*SubsuperscriptBox[\(\[ScriptCapitalV]\), \(v\), \
\((E)\)]\)= u\[Cross](u\[Cross]v) in Fourier space, in terms of the unit \
direction vector u={ux,uy,uz}.\nPolarization\[ScriptCapitalV]Electric[v,\
\[Theta],\[Phi]] gives the electric-type polarization vector \
\!\(\*SubsuperscriptBox[\(\[ScriptCapitalV]\), \(v\), \((E)\)]\)= u\[Cross](u\
\[Cross]v) in Fourier space, in terms of the polar coordinates (\[Theta],\
\[Phi]) of the unit direction vector u.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Polarization\[ScriptCapitalV]Magnetic", "::", "usage"}], "=", 
    "\"\<Polarization\[ScriptCapitalV]Magnetic[v,u] gives the electric-type \
polarization vector \!\(\*SubsuperscriptBox[\(\[ScriptCapitalV]\), \(v\), \
\((E)\)]\)= u\[Cross]v in Fourier space, in terms of the unit direction \
vector u={ux,uy,uz}.\n\
Polarization\[ScriptCapitalV]Magnetic[v,\[Theta],\[Phi]] gives the \
electric-type polarization vector \!\(\*SubsuperscriptBox[\(\[ScriptCapitalV]\
\), \(v\), \((E)\)]\)= u\[Cross]v in Fourier space, in terms of the polar \
coordinates (\[Theta],\[Phi]) of the unit direction vector u.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Polarization\[ScriptCapitalV]Helicity", "::", "usage"}], "=", 
    "\"\<Polarization\[ScriptCapitalV]Helicity[v,u] gives the electric-type \
polarization vector \!\(\*SubsuperscriptBox[\(\[ScriptCapitalV]\), \(v\), \
\((E)\)]\)= u\[Cross]v in Fourier space, in terms of the unit direction \
vector u={ux,uy,uz}.\n\
Polarization\[ScriptCapitalV]Helicity[v,\[Theta],\[Phi]] gives the \
electric-type polarization vector \!\(\*SubsuperscriptBox[\(\[ScriptCapitalV]\
\), \(v\), \((E)\)]\)= u\[Cross]v in Fourier space, in terms of the polar \
coordinates (\[Theta],\[Phi]) of the unit direction vector u.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Polarization\[ScriptCapitalV]Electric", "[", 
   RowBox[{"v_List", ",", "u_List"}], "]"}], ":=", 
  RowBox[{"Cross", "[", 
   RowBox[{"u", ",", 
    RowBox[{"Cross", "[", 
     RowBox[{"u", ",", "v"}], "]"}]}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Polarization\[ScriptCapitalV]Electric", "[", 
    RowBox[{"v_List", ",", "\[Theta]_", ",", "\[Phi]_"}], "]"}], ":=", 
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{"UnitU", "[", 
      RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}], ",", 
     RowBox[{"Cross", "[", 
      RowBox[{
       RowBox[{"UnitU", "[", 
        RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}], ",", "v"}], "]"}]}], 
    "]"}]}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Polarization\[ScriptCapitalV]Magnetic", "[", 
   RowBox[{"v_List", ",", "u_List"}], "]"}], ":=", 
  RowBox[{"Cross", "[", 
   RowBox[{"u", ",", "v"}], "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Polarization\[ScriptCapitalV]Magnetic", "[", 
    RowBox[{"v_List", ",", "\[Theta]_", ",", "\[Phi]_"}], "]"}], ":=", 
   RowBox[{"Cross", "[", 
    RowBox[{
     RowBox[{"UnitU", "[", 
      RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}], ",", "v"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Polarization\[ScriptCapitalV]Helicity", "[", 
   RowBox[{
    RowBox[{"s", ":", 
     RowBox[{"(", 
      RowBox[{"1", "|", 
       RowBox[{"-", "1"}]}], ")"}]}], ",", "u_List"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"Polarization\[ScriptCapitalV]Electric", "[", 
    RowBox[{
     RowBox[{"UnitE", "[", "s", "]"}], ",", "u"}], "]"}], "-", 
   RowBox[{"\[ImaginaryI]", " ", "s", " ", 
    RowBox[{"Polarization\[ScriptCapitalV]Magnetic", "[", 
     RowBox[{
      RowBox[{"UnitE", "[", "s", "]"}], ",", "u"}], 
     "]"}]}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Polarization\[ScriptCapitalV]Helicity", "[", 
    RowBox[{
     RowBox[{"s", ":", 
      RowBox[{"(", 
       RowBox[{"1", "|", 
        RowBox[{"-", "1"}]}], ")"}]}], ",", "\[Theta]_", ",", "\[Phi]_"}], 
    "]"}], ":=", 
   RowBox[{
    RowBox[{"Polarization\[ScriptCapitalV]Electric", "[", 
     RowBox[{
      RowBox[{"UnitE", "[", "s", "]"}], ",", 
      RowBox[{"UnitU", "[", 
       RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], "]"}], "-", 
    RowBox[{"\[ImaginaryI]", " ", "s", " ", 
     RowBox[{"Polarization\[ScriptCapitalV]Magnetic", "[", 
      RowBox[{
       RowBox[{"UnitE", "[", "s", "]"}], ",", 
       RowBox[{"UnitU", "[", 
        RowBox[{"\[Theta]", ",", "\[Phi]"}], "]"}]}], "]"}]}]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[58]:=",ExpressionUUID->"cb2890dd-d4d3-4448-9579-76a6088a8f5a"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Normalization", \
"Subsection",ExpressionUUID->"a13dc932-a3f1-47ce-bb6a-eded3eb06192"],

Cell[CellGroupData[{

Cell["CFnormTEM", \
"Subsubsection",ExpressionUUID->"da7807fa-4d0e-41ac-b4d9-c17267e3d0aa"],

Cell["\<\
Using partial memoization as per https://mathematica.stackexchange.com/q/21782\
\>", "Text",ExpressionUUID->"22636eef-7e67-467f-be47-6c2b85492e90"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CFnormTEM", "::", "usage"}], "=", 
    "\"\<CFnormTEM[l,m,q] returns the normalization integral \[Integral]|\!\(\
\*SubscriptBox[\(Y\), \(lm\)]\)(\[Theta],\[Phi])\!\(\*SuperscriptBox[\(|\), \
\(2\)]\)\!\(\*SuperscriptBox[\(e\), \(2  q\\\ cos \((\[Theta])\)\)]\)sin(\
\[Theta]\!\(\*SuperscriptBox[\()\), \(2\)]\)d\[CapitalOmega] for the TEM \
complex-focus fields.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]TEM", "::", "usage"}], "=", 
    "\"\<\[Alpha]TEM[l,m,q] returns the normalization constant \
CFnormTEM[l,m,q\!\(\*SuperscriptBox[\(]\), \(\(-1\)/2\)]\) for the TEM \
complex-focus fields.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]TEM", "[", 
   RowBox[{"l_", ",", "m_", ",", "q_"}], "]"}], ":=", 
  SuperscriptBox[
   RowBox[{"CFnormTEM", "[", 
    RowBox[{"l", ",", "m", ",", "q"}], "]"}], 
   RowBox[{
    RowBox[{"-", "1"}], "/", "2"}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]TEM", "[", 
    RowBox[{"l_", ",", "m_", ",", "0"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"\[Alpha]TEM", "[", 
     RowBox[{"l", ",", "m", ",", "0"}], "]"}], "=", 
    SuperscriptBox[
     RowBox[{"CFnormTEM", "[", 
      RowBox[{"l", ",", "m", ",", "0"}], "]"}], 
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}]]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CFnormTEM", "[", 
   RowBox[{"l_", ",", "m_", ",", "q_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "qInt", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"CFnormTEM", "[", 
       RowBox[{"l", ",", "m", ",", "qInt_"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"SphericalHarmonicY", "[", 
           RowBox[{"l", ",", "m", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], 
          RowBox[{"SphericalHarmonicY", "[", 
           RowBox[{"l", ",", 
            RowBox[{"-", "m"}], ",", "\[Theta]", ",", "\[Phi]"}], "]"}], 
          RowBox[{"Exp", "[", 
           RowBox[{"2", "qInt", " ", 
            RowBox[{"Cos", "[", "\[Theta]", "]"}]}], "]"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"Sin", "[", "\[Theta]", "]"}], ")"}], "2"], 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Phi]", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"CFnormTEM", "[", 
      RowBox[{"l", ",", "m", ",", "q"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CFnormTEM", "[", 
   RowBox[{"l_", ",", "m_", ",", "0"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"CFnormTEM", "[", 
    RowBox[{"l", ",", "m", ",", "0"}], "]"}], "=", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{"CFnormTEM", "[", 
      RowBox[{"l", ",", "m", ",", "q"}], "]"}], ",", 
     RowBox[{"q", "\[Rule]", "0"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[69]:=",ExpressionUUID->"7b97419a-30b2-4c66-a884-1d467c588673"]
}, Closed]],

Cell[CellGroupData[{

Cell["Special cases of CFnormTEM", \
"Subsubsection",ExpressionUUID->"45fb5853-4b17-4d95-baef-784411b22ae7"],

Cell[TextData[{
 "The partially-memoized evaluation in the definition of CFnormTEM ensures \
that the expensive symbolic integration is only ever performed once for each ",
 Cell[BoxData[
  FormBox[
   RowBox[{"l", ",", "m"}], TraditionalForm]],ExpressionUUID->
  "b95da716-3bb6-401d-b37a-a080bd0f7e2a"],
 " pair. However, this still means that the code will take a few seconds to \
run the first time that each pair is evaluated.\n\nThis can be mitigated by \
pre-computing the first few cases and including them as explicit definitions \
in the package .m file. To do that, the code below computes the first few \
cases and then writes them into the initialization cell below."
}], "Text",ExpressionUUID->"b0593bc0-0a6c-4cb1-88e4-e2d225c74f9c"],

Cell[BoxData[
 RowBox[{"NotebookWrite", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Cells", "[", 
     RowBox[{"CellTags", "\[Rule]", "\"\<CFNormTEM-SpecialCases\>\""}], "]"}],
     "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Cell", "[", 
    RowBox[{
     RowBox[{"BoxData", "[", 
      RowBox[{"RowBox", "[", 
       RowBox[{"Most", "[", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Join", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "\"\<(*This cell is auto-generated. Any changes will be \
over-ridden if the cell above is evaluated.*)\>\"", ",", 
             "\"\<\\\\[IndentingNewLine]\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Begin[\\\"`Private`\\\"];\>\"", ",", 
             "\"\<\\\\[IndentingNewLine]\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"{", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"\"\<CFnormTEM[\>\"", "<>", 
                  RowBox[{"ToString", "[", "l", "]"}], "<>", "\"\<,\>\"", "<>", 
                  RowBox[{"ToString", "[", "m", "]"}], "<>", "\"\<,q_]\>\""}],
                  ",", "\[IndentingNewLine]", "\"\<:=\>\"", ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{"ToString", "[", 
                  RowBox[{
                   RowBox[{"CFnormTEM", "[", 
                    RowBox[{"l", ",", "m", ",", "q"}], "]"}], ",", 
                   "InputForm"}], "]"}], ",", "\[IndentingNewLine]", 
                 "\"\<\\\\[IndentingNewLine]\>\""}], "\[IndentingNewLine]", 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"m", ",", 
                 RowBox[{"-", "l"}], ",", "l"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"l", ",", "0", ",", "3"}], "}"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"\"\<End[];\>\"", ",", "\"\<\\\\[IndentingNewLine]\>\""}],
             "}"}]}], "\[IndentingNewLine]", "]"}], "]"}], "]"}], "]"}], 
      "]"}], ",", "\"\<Input\>\"", ",", 
     RowBox[{"InitializationCell", "\[Rule]", "True"}], ",", 
     RowBox[{"CellTags", "\[Rule]", "\"\<CFNormTEM-SpecialCases\>\""}]}], 
    "\[IndentingNewLine]", "]"}], ",", "None", ",", 
   RowBox[{"AutoScroll", "\[Rule]", "False"}]}], 
  "]"}]], "Input",ExpressionUUID->"ae662f3b-c59c-4dce-8027-f7bd8597e2f3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"This", " ", "cell", " ", "is", " ", "auto"}], "-", 
    RowBox[{
     RowBox[{"generated", ".", " ", "Any"}], " ", "changes", " ", "will", " ",
      "be", " ", "over"}], "-", 
    RowBox[{
    "ridden", " ", "if", " ", "the", " ", "cell", " ", "above", " ", "is", 
     " ", 
     RowBox[{"evaluated", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"0", ",", "0", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"2", "*", "q", "*", 
        RowBox[{"Cosh", "[", 
         RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
       RowBox[{"Sinh", "[", 
        RowBox[{"2", "*", "q"}], "]"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", "*", 
       RowBox[{"q", "^", "3"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}], ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"18", "*", "q", "*", 
        RowBox[{"Cosh", "[", 
         RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
       RowBox[{"3", "*", 
        RowBox[{"(", 
         RowBox[{"3", " ", "+", " ", 
          RowBox[{"4", "*", 
           RowBox[{"q", "^", "2"}]}]}], ")"}], "*", 
        RowBox[{"Sinh", "[", 
         RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"8", "*", 
       RowBox[{"q", "^", "5"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"1", ",", "0", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"6", "*", "q", "*", 
        RowBox[{"(", 
         RowBox[{"3", " ", "+", " ", 
          RowBox[{"q", "^", "2"}]}], ")"}], "*", 
        RowBox[{"Cosh", "[", 
         RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
       RowBox[{"3", "*", 
        RowBox[{"(", 
         RowBox[{"3", " ", "+", " ", 
          RowBox[{"5", "*", 
           RowBox[{"q", "^", "2"}]}]}], ")"}], "*", 
        RowBox[{"Sinh", "[", 
         RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"4", "*", 
       RowBox[{"q", "^", "5"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"1", ",", "1", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"18", "*", "q", "*", 
        RowBox[{"Cosh", "[", 
         RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
       RowBox[{"3", "*", 
        RowBox[{"(", 
         RowBox[{"3", " ", "+", " ", 
          RowBox[{"4", "*", 
           RowBox[{"q", "^", "2"}]}]}], ")"}], "*", 
        RowBox[{"Sinh", "[", 
         RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"8", "*", 
       RowBox[{"q", "^", "5"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"2", ",", 
      RowBox[{"-", "2"}], ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"45", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", "q", "*", 
          RowBox[{"(", 
           RowBox[{"15", " ", "+", " ", 
            RowBox[{"4", "*", 
             RowBox[{"q", "^", "2"}]}]}], ")"}], "*", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
         RowBox[{"3", "*", 
          RowBox[{"(", 
           RowBox[{"5", " ", "+", " ", 
            RowBox[{"8", "*", 
             RowBox[{"q", "^", "2"}]}]}], ")"}], "*", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"64", "*", 
       RowBox[{"q", "^", "7"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}], ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"15", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"18", "*", "q", "*", 
          RowBox[{"(", 
           RowBox[{"5", " ", "+", " ", 
            RowBox[{"2", "*", 
             RowBox[{"q", "^", "2"}]}]}], ")"}], "*", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"45", " ", "+", " ", 
            RowBox[{"78", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"8", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}], "*", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"16", "*", 
       RowBox[{"q", "^", "7"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"2", ",", "0", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"5", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", "q", "*", 
          RowBox[{"(", 
           RowBox[{"405", " ", "+", " ", 
            RowBox[{"180", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"8", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}], "*", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"405", " ", "+", " ", 
            RowBox[{"720", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"104", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}], "*", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"32", "*", 
       RowBox[{"q", "^", "7"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"2", ",", "1", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"15", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"18", "*", "q", "*", 
          RowBox[{"(", 
           RowBox[{"5", " ", "+", " ", 
            RowBox[{"2", "*", 
             RowBox[{"q", "^", "2"}]}]}], ")"}], "*", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"45", " ", "+", " ", 
            RowBox[{"78", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"8", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}], "*", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"16", "*", 
       RowBox[{"q", "^", "7"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"2", ",", "2", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"45", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", "q", "*", 
          RowBox[{"(", 
           RowBox[{"15", " ", "+", " ", 
            RowBox[{"4", "*", 
             RowBox[{"q", "^", "2"}]}]}], ")"}], "*", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
         RowBox[{"3", "*", 
          RowBox[{"(", 
           RowBox[{"5", " ", "+", " ", 
            RowBox[{"8", "*", 
             RowBox[{"q", "^", "2"}]}]}], ")"}], "*", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"64", "*", 
       RowBox[{"q", "^", "7"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"3", ",", 
      RowBox[{"-", "3"}], ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"105", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"10", "*", "q", "*", 
          RowBox[{"(", 
           RowBox[{"21", " ", "+", " ", 
            RowBox[{"8", "*", 
             RowBox[{"q", "^", "2"}]}]}], ")"}], "*", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"105", " ", "+", " ", 
            RowBox[{"180", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"16", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}], "*", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"64", "*", 
       RowBox[{"q", "^", "9"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"3", ",", 
      RowBox[{"-", "2"}], ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"315", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", "q", "*", 
          RowBox[{"(", 
           RowBox[{"210", " ", "+", " ", 
            RowBox[{"95", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"4", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}], "*", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"210", " ", "+", " ", 
            RowBox[{"375", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"56", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}], "*", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"64", "*", 
       RowBox[{"q", "^", "9"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}], ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"21", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", "*", "q", "*", 
          RowBox[{"(", 
           RowBox[{"2625", " ", "+", " ", 
            RowBox[{"1300", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"96", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}], "*", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"7875", " ", "+", " ", 
            RowBox[{"64", "*", 
             RowBox[{"q", "^", "2"}], "*", 
             RowBox[{"(", 
              RowBox[{"225", " ", "+", " ", 
               RowBox[{"42", "*", 
                RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
               RowBox[{"q", "^", "4"}]}], ")"}]}]}], ")"}], "*", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"64", "*", 
       RowBox[{"q", "^", "9"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"3", ",", "0", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"7", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", "q", "*", 
          RowBox[{"(", 
           RowBox[{"15750", " ", "+", " ", 
            RowBox[{"8025", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"684", "*", 
             RowBox[{"q", "^", "4"}]}], " ", "+", " ", 
            RowBox[{"8", "*", 
             RowBox[{"q", "^", "6"}]}]}], ")"}], "*", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"15750", " ", "+", " ", 
            RowBox[{"29025", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"5784", "*", 
             RowBox[{"q", "^", "4"}]}], " ", "+", " ", 
            RowBox[{"200", "*", 
             RowBox[{"q", "^", "6"}]}]}], ")"}], "*", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"32", "*", 
       RowBox[{"q", "^", "9"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"3", ",", "1", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"21", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"6", "*", "q", "*", 
          RowBox[{"(", 
           RowBox[{"2625", " ", "+", " ", 
            RowBox[{"1300", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"96", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}], "*", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"7875", " ", "+", " ", 
            RowBox[{"64", "*", 
             RowBox[{"q", "^", "2"}], "*", 
             RowBox[{"(", 
              RowBox[{"225", " ", "+", " ", 
               RowBox[{"42", "*", 
                RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
               RowBox[{"q", "^", "4"}]}], ")"}]}]}], ")"}], "*", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"64", "*", 
       RowBox[{"q", "^", "9"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"3", ",", "2", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"315", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "*", "q", "*", 
          RowBox[{"(", 
           RowBox[{"210", " ", "+", " ", 
            RowBox[{"95", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"4", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}], "*", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"210", " ", "+", " ", 
            RowBox[{"375", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"56", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}], "*", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"64", "*", 
       RowBox[{"q", "^", "9"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormTEM", "[", 
     RowBox[{"3", ",", "3", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"105", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"10", "*", "q", "*", 
          RowBox[{"(", 
           RowBox[{"21", " ", "+", " ", 
            RowBox[{"8", "*", 
             RowBox[{"q", "^", "2"}]}]}], ")"}], "*", 
          RowBox[{"Cosh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}], " ", "-", " ", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"105", " ", "+", " ", 
            RowBox[{"180", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"16", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}], "*", 
          RowBox[{"Sinh", "[", 
           RowBox[{"2", "*", "q"}], "]"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"64", "*", 
       RowBox[{"q", "^", "9"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"End", "[", "]"}], ";"}]}]}]], "Input",
 InitializationCell->True,
 CellTags->"CFNormTEM-SpecialCases",
 CellLabel->"In[77]:=",ExpressionUUID->"2200bde6-c85d-4894-ba79-10a108545b34"],

Cell["\<\
To kick-start the process, run SetOptions[EvaluationCell[],CellTags\[Rule]\
\[CloseCurlyDoubleQuote]sample-cell-tag\[CloseCurlyDoubleQuote]] on the \
chosen cell with an appropriate cell tag.\
\>", "Text",ExpressionUUID->"70a41a6b-10e9-46cf-9824-a3fdc383cce1"]
}, Closed]],

Cell[CellGroupData[{

Cell["CFnormQuasiCircular", \
"Subsubsection",ExpressionUUID->"fdcd2fac-4a6d-4b8b-9d46-42d9193c461c"],

Cell["Using partial memoization as with CFnormTEM above.", \
"Text",ExpressionUUID->"7974c57a-27ae-4ce0-a1b7-921773f59f13"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "::", "usage"}], "=", 
    "\"\<CFnormQuasiCircular[l,m,q] returns the normalization integral \
\[Integral]|\!\(\*SubscriptBox[\(Y\), \
\(lm\)]\)(\[Theta],\[Phi])\!\(\*SuperscriptBox[\(|\), \
\(2\)]\)\!\(\*SuperscriptBox[\(e\), \(2  q\\\ cos \((\[Theta])\)\)]\)(1+cos(\
\[Theta])\!\(\*SuperscriptBox[\()\), \(2\)]\)d\[CapitalOmega] for the \
quasi-circular complex-focus fields.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"\[Alpha]QC", "::", "usage"}], "=", 
    "\"\<\[Alpha]QC[l,m,q] returns the normalization constant \
CFnormQuasiCircular[l,m,q\!\(\*SuperscriptBox[\(]\), \(\(-1\)/2\)]\) for the \
quasi-circular complex-focus fields.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\[Alpha]QC", "[", 
   RowBox[{"l_", ",", "m_", ",", "q_"}], "]"}], ":=", 
  SuperscriptBox[
   RowBox[{"CFnormQuasiCircular", "[", 
    RowBox[{"l", ",", "m", ",", "q"}], "]"}], 
   RowBox[{
    RowBox[{"-", "1"}], "/", "2"}]]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\[Alpha]QC", "[", 
    RowBox[{"l_", ",", "m_", ",", "0"}], "]"}], ":=", 
   RowBox[{
    RowBox[{"\[Alpha]QC", "[", 
     RowBox[{"l", ",", "m", ",", "0"}], "]"}], "=", 
    SuperscriptBox[
     RowBox[{"CFnormQuasiCircular", "[", 
      RowBox[{"l", ",", "m", ",", "0"}], "]"}], 
     RowBox[{
      RowBox[{"-", "1"}], "/", "2"}]]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CFnormQuasiCircular", "[", 
   RowBox[{"l_", ",", "m_", ",", "q_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", "qInt", "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"CFnormQuasiCircular", "[", 
       RowBox[{"l", ",", "m", ",", "qInt_"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"Integrate", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"SphericalHarmonicY", "[", 
           RowBox[{"l", ",", "m", ",", "\[Theta]", ",", "\[Phi]"}], "]"}], 
          RowBox[{"SphericalHarmonicY", "[", 
           RowBox[{"l", ",", 
            RowBox[{"-", "m"}], ",", "\[Theta]", ",", "\[Phi]"}], "]"}], 
          RowBox[{"Exp", "[", 
           RowBox[{"2", 
            RowBox[{"qIntCos", "[", "\[Theta]", "]"}]}], "]"}], 
          SuperscriptBox[
           RowBox[{"(", 
            RowBox[{"1", "+", 
             RowBox[{"Cos", "[", "\[Theta]", "]"}]}], ")"}], "2"], 
          RowBox[{"Sin", "[", "\[Theta]", "]"}]}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Theta]", ",", "0", ",", "\[Pi]"}], "}"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Phi]", ",", "0", ",", 
           RowBox[{"2", "\[Pi]"}]}], "}"}]}], "]"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"CFnormQuasiCircular", "[", 
      RowBox[{"l", ",", "m", ",", "q"}], "]"}]}]}], "\[IndentingNewLine]", 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"CFnormQuasiCircular", "[", 
   RowBox[{"l_", ",", "m_", ",", "0"}], "]"}], ":=", 
  RowBox[{
   RowBox[{"CFnormQuasiCircular", "[", 
    RowBox[{"l", ",", "m", ",", "0"}], "]"}], "=", 
   RowBox[{"Limit", "[", 
    RowBox[{
     RowBox[{"CFnormQuasiCircular", "[", 
      RowBox[{"l", ",", "m", ",", "q"}], "]"}], ",", 
     RowBox[{"q", "\[Rule]", "0"}]}], "]"}]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[95]:=",ExpressionUUID->"b67db601-638a-4878-a6ff-13759b1c50ac"]
}, Closed]],

Cell[CellGroupData[{

Cell["Special cases of CFnormQuasiCircular", \
"Subsubsection",ExpressionUUID->"4a599663-c109-4233-8ffc-e9c45ca6faad"],

Cell["\<\
Identical to the CFnormTEM special-case handling above, but for \
CFnormQuasiCircular.\
\>", "Text",ExpressionUUID->"665f533d-960c-42ea-b115-954637f46da7"],

Cell[BoxData[
 RowBox[{"NotebookWrite", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Cells", "[", 
     RowBox[{
     "CellTags", "\[Rule]", "\"\<CFnormQuasiCircular-SpecialCases\>\""}], 
     "]"}], "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Cell", "[", 
    RowBox[{
     RowBox[{"BoxData", "[", 
      RowBox[{"RowBox", "[", 
       RowBox[{"Most", "[", 
        RowBox[{"Flatten", "[", 
         RowBox[{"Join", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{
            "\"\<(*This cell is auto-generated. Any changes will be \
over-ridden if the cell above is evaluated.*)\>\"", ",", 
             "\"\<\\\\[IndentingNewLine]\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Begin[\\\"`Private`\\\"];\>\"", ",", 
             "\"\<\\\\[IndentingNewLine]\>\""}], "}"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"Table", "[", 
            RowBox[{
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"{", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"\"\<CFnormQuasiCircular[\>\"", "<>", 
                  RowBox[{"ToString", "[", "l", "]"}], "<>", "\"\<,\>\"", "<>", 
                  RowBox[{"ToString", "[", "m", "]"}], "<>", "\"\<,q_]\>\""}],
                  ",", "\[IndentingNewLine]", "\"\<:=\>\"", ",", 
                 "\[IndentingNewLine]", 
                 RowBox[{"ToString", "[", 
                  RowBox[{
                   RowBox[{"CFnormQuasiCircular", "[", 
                    RowBox[{"l", ",", "m", ",", "q"}], "]"}], ",", 
                   "InputForm"}], "]"}], ",", "\[IndentingNewLine]", 
                 "\"\<\\\\[IndentingNewLine]\>\""}], "\[IndentingNewLine]", 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"m", ",", 
                 RowBox[{"-", "l"}], ",", "l"}], "}"}]}], "]"}], ",", 
             RowBox[{"{", 
              RowBox[{"l", ",", "0", ",", "3"}], "}"}]}], "]"}], ",", 
           "\[IndentingNewLine]", 
           RowBox[{"{", 
            RowBox[{"\"\<End[];\>\"", ",", "\"\<\\\\[IndentingNewLine]\>\""}],
             "}"}]}], "\[IndentingNewLine]", "]"}], "]"}], "]"}], "]"}], 
      "]"}], ",", "\"\<Input\>\"", ",", 
     RowBox[{"InitializationCell", "\[Rule]", "True"}], ",", 
     RowBox[{
     "CellTags", "\[Rule]", "\"\<CFnormQuasiCircular-SpecialCases\>\""}]}], 
    "\[IndentingNewLine]", "]"}], ",", "None", ",", 
   RowBox[{"AutoScroll", "\[Rule]", "False"}]}], 
  "]"}]], "Input",ExpressionUUID->"5d4b04ae-8d3a-4d0c-92df-28286bb50c9c"],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"This", " ", "cell", " ", "is", " ", "auto"}], "-", 
    RowBox[{
     RowBox[{"generated", ".", " ", "Any"}], " ", "changes", " ", "will", " ",
      "be", " ", "over"}], "-", 
    RowBox[{
    "ridden", " ", "if", " ", "the", " ", "cell", " ", "above", " ", "is", 
     " ", 
     RowBox[{"evaluated", "."}]}]}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"0", ",", "0", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "1"}], " ", "+", " ", 
       RowBox[{
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"4", "*", "q"}], ")"}]}], "*", 
        RowBox[{"(", 
         RowBox[{"1", " ", "-", " ", 
          RowBox[{"4", "*", "q"}], " ", "+", " ", 
          RowBox[{"8", "*", 
           RowBox[{"q", "^", "2"}]}]}], ")"}]}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"8", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "3"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"1", ",", 
      RowBox[{"-", "1"}], ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "3"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", "*", 
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", "q"}], ")"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{"4", "*", "q"}], ")"}]}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], " ", "+", " ", 
            RowBox[{"9", "*", "q"}], " ", "-", " ", 
            RowBox[{"12", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"8", "*", 
             RowBox[{"q", "^", "3"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"16", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "5"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"1", ",", "0", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"3", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "3"}], " ", "-", " ", 
         RowBox[{"3", "*", "q"}], " ", "-", " ", 
         RowBox[{"q", "^", "2"}], " ", "+", " ", 
         RowBox[{
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{"4", "*", "q"}], ")"}]}], "*", 
          RowBox[{"(", 
           RowBox[{"3", " ", "-", " ", 
            RowBox[{"9", "*", "q"}], " ", "+", " ", 
            RowBox[{"13", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "-", " ", 
            RowBox[{"12", "*", 
             RowBox[{"q", "^", "3"}]}], " ", "+", " ", 
            RowBox[{"8", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"8", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "5"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"1", ",", "1", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "3"}], "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"3", "*", 
          RowBox[{"(", 
           RowBox[{"1", " ", "+", " ", "q"}], ")"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{"4", "*", "q"}], ")"}]}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "3"}], " ", "+", " ", 
            RowBox[{"9", "*", "q"}], " ", "-", " ", 
            RowBox[{"12", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"8", "*", 
             RowBox[{"q", "^", "3"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"16", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "5"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"2", ",", 
      RowBox[{"-", "2"}], ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"15", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], "*", 
          RowBox[{"(", 
           RowBox[{"15", " ", "+", " ", 
            RowBox[{"20", "*", "q"}], " ", "+", " ", 
            RowBox[{"8", "*", 
             RowBox[{"q", "^", "2"}]}]}], ")"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{"4", "*", "q"}], ")"}]}], "*", 
          RowBox[{"(", 
           RowBox[{"45", " ", "-", " ", 
            RowBox[{"120", "*", "q"}], " ", "+", " ", 
            RowBox[{"144", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "-", " ", 
            RowBox[{"96", "*", 
             RowBox[{"q", "^", "3"}]}], " ", "+", " ", 
            RowBox[{"32", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"128", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "7"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"2", ",", 
      RowBox[{"-", "1"}], ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "15"}], "*", 
       RowBox[{"(", 
        RowBox[{"45", " ", "+", " ", 
         RowBox[{"60", "*", "q"}], " ", "+", " ", 
         RowBox[{"30", "*", 
          RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
         RowBox[{"6", "*", 
          RowBox[{"q", "^", "3"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{"4", "*", "q"}], ")"}]}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "45"}], " ", "+", " ", 
            RowBox[{"120", "*", "q"}], " ", "-", " ", 
            RowBox[{"150", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"114", "*", 
             RowBox[{"q", "^", "3"}]}], " ", "-", " ", 
            RowBox[{"56", "*", 
             RowBox[{"q", "^", "4"}]}], " ", "+", " ", 
            RowBox[{"16", "*", 
             RowBox[{"q", "^", "5"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"32", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "7"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"2", ",", "0", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"5", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", "405"}], " ", "-", " ", 
         RowBox[{"4", "*", "q", "*", 
          RowBox[{"(", 
           RowBox[{"135", " ", "+", " ", 
            RowBox[{"2", "*", "q", "*", 
             RowBox[{"(", 
              RowBox[{"36", " ", "+", " ", 
               RowBox[{"q", "*", 
                RowBox[{"(", 
                 RowBox[{"9", " ", "+", " ", "q"}], ")"}]}]}], ")"}]}]}], 
           ")"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{"4", "*", "q"}], ")"}]}], "*", 
          RowBox[{"(", 
           RowBox[{"405", " ", "+", " ", 
            RowBox[{"8", "*", "q", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "135"}], " ", "+", " ", 
               RowBox[{"q", "*", 
                RowBox[{"(", 
                 RowBox[{"171", " ", "+", " ", 
                  RowBox[{"q", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "135"}], " ", "+", " ", 
                    RowBox[{"q", "*", 
                    RowBox[{"(", 
                    RowBox[{"73", " ", "+", " ", 
                    RowBox[{"4", "*", "q", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "7"}], " ", "+", " ", 
                    RowBox[{"2", "*", "q"}]}], ")"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"64", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "7"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"2", ",", "1", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{"-", "15"}], "*", 
       RowBox[{"(", 
        RowBox[{"45", " ", "+", " ", 
         RowBox[{"60", "*", "q"}], " ", "+", " ", 
         RowBox[{"30", "*", 
          RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
         RowBox[{"6", "*", 
          RowBox[{"q", "^", "3"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{"4", "*", "q"}], ")"}]}], "*", 
          RowBox[{"(", 
           RowBox[{
            RowBox[{"-", "45"}], " ", "+", " ", 
            RowBox[{"120", "*", "q"}], " ", "-", " ", 
            RowBox[{"150", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "+", " ", 
            RowBox[{"114", "*", 
             RowBox[{"q", "^", "3"}]}], " ", "-", " ", 
            RowBox[{"56", "*", 
             RowBox[{"q", "^", "4"}]}], " ", "+", " ", 
            RowBox[{"16", "*", 
             RowBox[{"q", "^", "5"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"32", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "7"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"2", ",", "2", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"15", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], "*", 
          RowBox[{"(", 
           RowBox[{"15", " ", "+", " ", 
            RowBox[{"20", "*", "q"}], " ", "+", " ", 
            RowBox[{"8", "*", 
             RowBox[{"q", "^", "2"}]}]}], ")"}]}], " ", "+", " ", 
         RowBox[{
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{"4", "*", "q"}], ")"}]}], "*", 
          RowBox[{"(", 
           RowBox[{"45", " ", "-", " ", 
            RowBox[{"120", "*", "q"}], " ", "+", " ", 
            RowBox[{"144", "*", 
             RowBox[{"q", "^", "2"}]}], " ", "-", " ", 
            RowBox[{"96", "*", 
             RowBox[{"q", "^", "3"}]}], " ", "+", " ", 
            RowBox[{"32", "*", 
             RowBox[{"q", "^", "4"}]}]}], ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"128", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "7"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"3", ",", 
      RowBox[{"-", "3"}], ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "525"}], "*", 
        RowBox[{"(", 
         RowBox[{"42", " ", "+", " ", 
          RowBox[{"q", "*", 
           RowBox[{"(", 
            RowBox[{"63", " ", "+", " ", 
             RowBox[{"4", "*", "q", "*", 
              RowBox[{"(", 
               RowBox[{"9", " ", "+", " ", 
                RowBox[{"2", "*", "q"}]}], ")"}]}]}], ")"}]}]}], ")"}]}], " ",
        "-", " ", 
       RowBox[{"105", "*", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"4", "*", "q"}], ")"}]}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "210"}], " ", "+", " ", 
          RowBox[{"q", "*", 
           RowBox[{"(", 
            RowBox[{"525", " ", "+", " ", 
             RowBox[{"8", "*", "q", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "75"}], " ", "+", " ", 
                RowBox[{"2", "*", "q", "*", 
                 RowBox[{"(", 
                  RowBox[{"25", " ", "+", " ", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], " ", "+", " ", "q"}], ")"}], "*", 
                    "q"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"256", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "9"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"3", ",", 
      RowBox[{"-", "2"}], ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"105", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], "*", 
          RowBox[{"(", 
           RowBox[{"210", " ", "+", " ", 
            RowBox[{"q", "*", 
             RowBox[{"(", 
              RowBox[{"315", " ", "+", " ", 
               RowBox[{"q", "*", 
                RowBox[{"(", 
                 RowBox[{"195", " ", "+", " ", 
                  RowBox[{"60", "*", "q"}], " ", "+", " ", 
                  RowBox[{"8", "*", 
                   RowBox[{"q", "^", "2"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}],
          " ", "+", " ", 
         RowBox[{
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{"4", "*", "q"}], ")"}]}], "*", 
          RowBox[{"(", 
           RowBox[{"630", " ", "+", " ", 
            RowBox[{"q", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1575"}], " ", "+", " ", 
               RowBox[{"q", "*", 
                RowBox[{"(", 
                 RowBox[{"1845", " ", "+", " ", 
                  RowBox[{"8", "*", "q", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "165"}], " ", "+", " ", 
                    RowBox[{"2", "*", "q", "*", 
                    RowBox[{"(", 
                    RowBox[{"39", " ", "+", " ", 
                    RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6"}], " ", "+", " ", "q"}], ")"}], "*", 
                    "q"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"128", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "9"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"3", ",", 
      RowBox[{"-", "1"}], ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "63"}], "*", 
        RowBox[{"(", 
         RowBox[{"5250", " ", "+", " ", 
          RowBox[{"q", "*", 
           RowBox[{"(", 
            RowBox[{"7875", " ", "+", " ", 
             RowBox[{"4", "*", "q", "*", 
              RowBox[{"(", 
               RowBox[{"1275", " ", "+", " ", 
                RowBox[{"2", "*", "q", "*", 
                 RowBox[{"(", 
                  RowBox[{"225", " ", "+", " ", 
                   RowBox[{"4", "*", "q", "*", 
                    RowBox[{"(", 
                    RowBox[{"11", " ", "+", " ", "q"}], ")"}]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}], " ", "-", " ", 
       RowBox[{"21", "*", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"4", "*", "q"}], ")"}]}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "15750"}], " ", "+", " ", 
          RowBox[{"q", "*", 
           RowBox[{"(", 
            RowBox[{"39375", " ", "+", " ", 
             RowBox[{"16", "*", "q", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2925"}], " ", "+", " ", 
                RowBox[{"q", "*", 
                 RowBox[{"(", 
                  RowBox[{"2175", " ", "+", " ", 
                   RowBox[{"4", "*", "q", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "279"}], " ", "+", " ", 
                    RowBox[{"2", "*", "q", "*", 
                    RowBox[{"(", 
                    RowBox[{"51", " ", "+", " ", 
                    RowBox[{"q", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "13"}], " ", "+", " ", 
                    RowBox[{"2", "*", "q"}]}], ")"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"256", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "9"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"3", ",", "0", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "55125"}], "*", 
        RowBox[{"(", 
         RowBox[{"2", " ", "+", " ", 
          RowBox[{"3", "*", "q"}]}], ")"}]}], " ", "-", " ", 
       RowBox[{"7", "*", 
        RowBox[{"q", "^", "2"}], "*", 
        RowBox[{"(", 
         RowBox[{"15525", " ", "+", " ", 
          RowBox[{"4", "*", "q", "*", 
           RowBox[{"(", 
            RowBox[{"1425", " ", "+", " ", 
             RowBox[{"2", "*", "q", "*", 
              RowBox[{"(", 
               RowBox[{"153", " ", "+", " ", 
                RowBox[{"q", "*", 
                 RowBox[{"(", 
                  RowBox[{"18", " ", "+", " ", "q"}], ")"}]}]}], ")"}]}]}], 
            ")"}]}]}], ")"}]}], " ", "+", " ", 
       RowBox[{"7", "*", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"4", "*", "q"}], ")"}]}], "*", 
        RowBox[{"(", 
         RowBox[{"15750", " ", "+", " ", 
          RowBox[{"q", "*", 
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "39375"}], " ", "+", " ", 
             RowBox[{"q", "*", 
              RowBox[{"(", 
               RowBox[{"47025", " ", "+", " ", 
                RowBox[{"8", "*", "q", "*", 
                 RowBox[{"(", 
                  RowBox[{
                   RowBox[{"-", "4425"}], " ", "+", " ", 
                   RowBox[{"q", "*", 
                    RowBox[{"(", 
                    RowBox[{"2328", " ", "+", " ", 
                    RowBox[{"q", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "894"}], " ", "+", " ", 
                    RowBox[{"q", "*", 
                    RowBox[{"(", 
                    RowBox[{"253", " ", "-", " ", 
                    RowBox[{"52", "*", "q"}], " ", "+", " ", 
                    RowBox[{"8", "*", 
                    RowBox[{"q", "^", "2"}]}]}], ")"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"64", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "9"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"3", ",", "1", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "63"}], "*", 
        RowBox[{"(", 
         RowBox[{"5250", " ", "+", " ", 
          RowBox[{"q", "*", 
           RowBox[{"(", 
            RowBox[{"7875", " ", "+", " ", 
             RowBox[{"4", "*", "q", "*", 
              RowBox[{"(", 
               RowBox[{"1275", " ", "+", " ", 
                RowBox[{"2", "*", "q", "*", 
                 RowBox[{"(", 
                  RowBox[{"225", " ", "+", " ", 
                   RowBox[{"4", "*", "q", "*", 
                    RowBox[{"(", 
                    RowBox[{"11", " ", "+", " ", "q"}], ")"}]}]}], ")"}]}]}], 
               ")"}]}]}], ")"}]}]}], ")"}]}], " ", "-", " ", 
       RowBox[{"21", "*", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"4", "*", "q"}], ")"}]}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "15750"}], " ", "+", " ", 
          RowBox[{"q", "*", 
           RowBox[{"(", 
            RowBox[{"39375", " ", "+", " ", 
             RowBox[{"16", "*", "q", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "2925"}], " ", "+", " ", 
                RowBox[{"q", "*", 
                 RowBox[{"(", 
                  RowBox[{"2175", " ", "+", " ", 
                   RowBox[{"4", "*", "q", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "279"}], " ", "+", " ", 
                    RowBox[{"2", "*", "q", "*", 
                    RowBox[{"(", 
                    RowBox[{"51", " ", "+", " ", 
                    RowBox[{"q", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "13"}], " ", "+", " ", 
                    RowBox[{"2", "*", "q"}]}], ")"}]}]}], ")"}]}]}], 
                    ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"256", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "9"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"3", ",", "2", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"105", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], "*", 
          RowBox[{"(", 
           RowBox[{"210", " ", "+", " ", 
            RowBox[{"q", "*", 
             RowBox[{"(", 
              RowBox[{"315", " ", "+", " ", 
               RowBox[{"q", "*", 
                RowBox[{"(", 
                 RowBox[{"195", " ", "+", " ", 
                  RowBox[{"60", "*", "q"}], " ", "+", " ", 
                  RowBox[{"8", "*", 
                   RowBox[{"q", "^", "2"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}],
          " ", "+", " ", 
         RowBox[{
          RowBox[{"E", "^", 
           RowBox[{"(", 
            RowBox[{"4", "*", "q"}], ")"}]}], "*", 
          RowBox[{"(", 
           RowBox[{"630", " ", "+", " ", 
            RowBox[{"q", "*", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"-", "1575"}], " ", "+", " ", 
               RowBox[{"q", "*", 
                RowBox[{"(", 
                 RowBox[{"1845", " ", "+", " ", 
                  RowBox[{"8", "*", "q", "*", 
                   RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "165"}], " ", "+", " ", 
                    RowBox[{"2", "*", "q", "*", 
                    RowBox[{"(", 
                    RowBox[{"39", " ", "+", " ", 
                    RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "6"}], " ", "+", " ", "q"}], ")"}], "*", 
                    "q"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
           ")"}]}]}], ")"}]}], ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"128", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "9"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"CFnormQuasiCircular", "[", 
     RowBox[{"3", ",", "3", ",", "q_"}], "]"}], ":=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "525"}], "*", 
        RowBox[{"(", 
         RowBox[{"42", " ", "+", " ", 
          RowBox[{"q", "*", 
           RowBox[{"(", 
            RowBox[{"63", " ", "+", " ", 
             RowBox[{"4", "*", "q", "*", 
              RowBox[{"(", 
               RowBox[{"9", " ", "+", " ", 
                RowBox[{"2", "*", "q"}]}], ")"}]}]}], ")"}]}]}], ")"}]}], " ",
        "-", " ", 
       RowBox[{"105", "*", 
        RowBox[{"E", "^", 
         RowBox[{"(", 
          RowBox[{"4", "*", "q"}], ")"}]}], "*", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"-", "210"}], " ", "+", " ", 
          RowBox[{"q", "*", 
           RowBox[{"(", 
            RowBox[{"525", " ", "+", " ", 
             RowBox[{"8", "*", "q", "*", 
              RowBox[{"(", 
               RowBox[{
                RowBox[{"-", "75"}], " ", "+", " ", 
                RowBox[{"2", "*", "q", "*", 
                 RowBox[{"(", 
                  RowBox[{"25", " ", "+", " ", 
                   RowBox[{"2", "*", 
                    RowBox[{"(", 
                    RowBox[{
                    RowBox[{"-", "5"}], " ", "+", " ", "q"}], ")"}], "*", 
                    "q"}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], ")"}]}]}], 
      ")"}], "/", 
     RowBox[{"(", 
      RowBox[{"256", "*", 
       RowBox[{"E", "^", 
        RowBox[{"(", 
         RowBox[{"2", "*", "q"}], ")"}]}], "*", 
       RowBox[{"q", "^", "9"}]}], ")"}]}]}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"End", "[", "]"}], ";"}]}]}]], "Input",
 InitializationCell->True,
 CellTags->"CFnormQuasiCircular-SpecialCases",
 CellLabel->"In[103]:=",ExpressionUUID->"a58f2859-3cd6-4dcd-887c-05802dbd8793"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Fields", \
"Subsection",ExpressionUUID->"3effdee2-50e9-4205-8d03-ef0700f800a7"],

Cell[CellGroupData[{

Cell["\<\
ComplexFocusHelicityE, ComplexFocusElectricE, ComplexFocusMagneticE\
\>", "Subsubsection",ExpressionUUID->"9c5b6259-b711-45c0-8483-700e5c48a49e"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"ComplexFocusHelicityE", "::", "usage"}], "=", 
   "\"\<ComplexFocusHelicityE[l,m,\[Sigma],{x,y,z},\[Zeta]] gives the \
complex-focus field of helicity type, with complex-focus parameter \[Zeta], \
angular momentum numbers l,m and helicity \[Sigma]=\[PlusMinus]1.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"ComplexFocusElectricE", "::", "usage"}], "=", 
   "\"\<ComplexFocusElectricE[l,m,v,{x,y,z},\[Zeta]] gives the complex-focus \
field of electric type, with complex-focus parameter \[Zeta], angular \
momentum numbers l,m and seed polarization vector v.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"ComplexFocusMagneticE", "::", "usage"}], "=", 
    "\"\<ComplexFocusMagneticE[l,m,v,{x,y,z},\[Zeta]] gives the complex-focus \
field of magnetic type, with complex-focus parameter \[Zeta], angular \
momentum numbers l,m and seed polarization vector v.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ComplexFocusHelicityE", "[", 
   RowBox[{"l_", ",", "m_", ",", 
    RowBox[{"s", ":", 
     RowBox[{"(", 
      RowBox[{"1", "|", 
       RowBox[{"-", "1"}]}], ")"}]}], ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], ",", "\[Zeta]_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"xInt", ",", "yInt", ",", "zInt", ",", "\[Zeta]Int"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ComplexFocusHelicityE", "[", 
       RowBox[{"l", ",", "m", ",", "s", ",", 
        RowBox[{"{", 
         RowBox[{"xInt_", ",", "yInt_", ",", "zInt_"}], "}"}], ",", 
        "\[Zeta]Int_"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"PolarizationVHelicity", "[", 
        RowBox[{"s", ",", 
         RowBox[{"Multipole\[CapitalLambda]", "[", 
          RowBox[{"l", ",", "m", ",", 
           RowBox[{"{", 
            RowBox[{"xInt", ",", "yInt", ",", 
             RowBox[{"zInt", "-", 
              RowBox[{"\[ImaginaryI]", " ", "\[Zeta]Int"}]}]}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"xInt", ",", "yInt", ",", "zInt"}], "}"}]}], "]"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"ComplexFocusHelicityE", "[", 
      RowBox[{"l", ",", "m", ",", "s", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "\[Zeta]"}], "]"}]}]}],
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ComplexFocusElectricE", "[", 
   RowBox[{"l_", ",", "m_", ",", "vector_", ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], ",", "\[Zeta]_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"xInt", ",", "yInt", ",", "zInt", ",", "\[Zeta]Int"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ComplexFocusElectricE", "[", 
       RowBox[{"l", ",", "m", ",", "vector", ",", 
        RowBox[{"{", 
         RowBox[{"xInt_", ",", "yInt_", ",", "zInt_"}], "}"}], ",", 
        "\[Zeta]Int_"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"PolarizationVElectric", "[", 
        RowBox[{"vector", ",", 
         RowBox[{"Multipole\[CapitalLambda]", "[", 
          RowBox[{"l", ",", "m", ",", 
           RowBox[{"{", 
            RowBox[{"xInt", ",", "yInt", ",", 
             RowBox[{"zInt", "-", 
              RowBox[{"\[ImaginaryI]", " ", "\[Zeta]Int"}]}]}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"xInt", ",", "yInt", ",", "zInt"}], "}"}]}], "]"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"ComplexFocusElectricE", "[", 
      RowBox[{"l", ",", "m", ",", "vector", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "\[Zeta]"}], "]"}]}]}],
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ComplexFocusMagneticE", "[", 
   RowBox[{"l_", ",", "m_", ",", "vector_", ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], ",", "\[Zeta]_"}], "]"}], ":=", 
  RowBox[{"Block", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"xInt", ",", "yInt", ",", "zInt", ",", "\[Zeta]Int"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{
      RowBox[{"ComplexFocusMagneticE", "[", 
       RowBox[{"l", ",", "m", ",", "vector", ",", 
        RowBox[{"{", 
         RowBox[{"xInt_", ",", "yInt_", ",", "zInt_"}], "}"}], ",", 
        "\[Zeta]Int_"}], "]"}], "=", 
      RowBox[{"Simplify", "[", 
       RowBox[{"PolarizationVMagnetic", "[", 
        RowBox[{"vector", ",", 
         RowBox[{"Multipole\[CapitalLambda]", "[", 
          RowBox[{"l", ",", "m", ",", 
           RowBox[{"{", 
            RowBox[{"xInt", ",", "yInt", ",", 
             RowBox[{"zInt", "-", 
              RowBox[{"\[ImaginaryI]", " ", "\[Zeta]Int"}]}]}], "}"}]}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"xInt", ",", "yInt", ",", "zInt"}], "}"}]}], "]"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"ComplexFocusMagneticE", "[", 
      RowBox[{"l", ",", "m", ",", "vector", ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "\[Zeta]"}], "]"}]}]}],
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[121]:=",ExpressionUUID->"8ff8dcce-571d-421e-b883-9b3f923a1d9c"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Polarization analysis functions", \
"Subsection",ExpressionUUID->"8a8dc1bc-2218-4913-b28b-2e1859938a3b"],

Cell[CellGroupData[{

Cell["JonesPhase", \
"Subsubsection",ExpressionUUID->"1697251d-ce24-417f-b22a-46d4896873fb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"JonesPhase", "::", "usage"}], "=", 
    "\"\<JonesPhase[v] gives the Jones phase of the vector v, \
\!\(\*FractionBox[\(1\), \(2\)]\)arg(v\[CenterDot]v).\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"JonesPhase", "[", "vec_", "]"}], ":=", 
    RowBox[{
     RowBox[{"Arg", "[", 
      RowBox[{"Dot", "[", 
       RowBox[{"vec", ",", "vec"}], "]"}], "]"}], "/", "2"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[129]:=",ExpressionUUID->"0c1cb73c-6689-4313-b0bc-f40e1260bc3f"]
}, Closed]],

Cell[CellGroupData[{

Cell["JonesMajorAxisA", \
"Subsubsection",ExpressionUUID->"41580f7a-c3c1-4066-abec-ff83f511372b"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"JonesMajorAxisA", "::", "usage"}], "=", 
    "\"\<JonesMajorAxisA[v] gives the major-axis vector of the polarization \
ellipse marked by the complex vector v.\nJonesMajorAxisA[v,normFunction] \
normalizes the ellipse by normFunction[v].\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"JonesMajorAxisA", "[", 
    RowBox[{"vec_", ",", 
     RowBox[{"normFunction_", ":", 
      RowBox[{"(", 
       RowBox[{"1", "&"}], ")"}]}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "vecF", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"vecF", "=", 
       RowBox[{"vec", " ", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "I"}], " ", 
          RowBox[{"JonesPhase", "[", "vec", "]"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Re", "[", "vecF", "]"}], "/", 
       RowBox[{"normFunction", "[", "vecF", "]"}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[133]:=",ExpressionUUID->"110c80e3-a235-4497-98ce-7cfa58f6e56a"]
}, Closed]],

Cell[CellGroupData[{

Cell["JonesMinorAxisB", \
"Subsubsection",ExpressionUUID->"4c974227-3f6c-4768-aa9f-5e88cab41cca"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"JonesMinorAxisB", "::", "usage"}], "=", 
    "\"\<JonesMinorAxisB[v] gives the minor-axis vector of the polarization \
ellipse marked by the complex vector v.\nJonesMinorAxisB[v,normFunction] \
normalizes the ellipse by normFunction[v].\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"JonesMinorAxisB", "[", 
    RowBox[{"vec_", ",", 
     RowBox[{"normFunction_", ":", 
      RowBox[{"(", 
       RowBox[{"1", "&"}], ")"}]}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "vecF", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"vecF", "=", 
       RowBox[{"vec", " ", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "I"}], " ", 
          RowBox[{"JonesPhase", "[", "vec", "]"}]}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{"Im", "[", "vecF", "]"}], "/", 
       RowBox[{"normFunction", "[", "vecF", "]"}]}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[137]:=",ExpressionUUID->"bc7c0151-fda6-4a02-a32b-a47c4cd6df32"]
}, Closed]],

Cell[CellGroupData[{

Cell["SpinE", \
"Subsubsection",ExpressionUUID->"66caace8-3ec1-4dd8-b1a8-1a63629ac4b2"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"SpinE", "::", "usage"}], "=", 
    "\"\<SpinE[E] gives the electric spin angular momentum vector \
\!\(\*FractionBox[\(1\), \(\(|\)\(E\)\*SuperscriptBox[\(|\), \(2\)]\)]\)Im(E\
\[Conjugate]\[Cross]E) for a complex electric-field amplitude E.\>\""}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"SpinE", "[", "vec_", "]"}], ":=", 
   RowBox[{
    RowBox[{"Im", "[", 
     RowBox[{"Cross", "[", 
      RowBox[{
       RowBox[{"Conjugate", "[", "vec", "]"}], ",", "vec"}], "]"}], "]"}], 
    "/", 
    SuperscriptBox[
     RowBox[{"Norm", "[", "vec", "]"}], "2"]}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[141]:=",ExpressionUUID->"f8b485a1-8b21-4f80-b8fb-239014de9345"]
}, Closed]],

Cell[CellGroupData[{

Cell["Poincarana", \
"Subsubsection",ExpressionUUID->"55ba8731-ed80-4d8b-a43b-8746a95404ac"],

Cell[TextData[{
 "Poincarana description of the polarization, as described in\n",
 StyleBox[" ",
  FontSize->1],
 "\n    Geometric phases in 2D and 3D polarized fields: geometrical, \
dynamical, and topological aspects. KY Bliokh, MA Alonso and MR Dennis. ",
 StyleBox[ButtonBox["Rep. Prog. Phys.",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1088/1361-6633/ab4415"], None},
  ButtonNote->"https://doi.org/10.1088/1361-6633/ab4415"],
  FontSlant->"Italic"],
 ButtonBox[" ",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1088/1361-6633/ab4415"], None},
  ButtonNote->"https://doi.org/10.1088/1361-6633/ab4415"],
 StyleBox[ButtonBox["82",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1088/1361-6633/ab4415"], None},
  ButtonNote->"https://doi.org/10.1088/1361-6633/ab4415"],
  FontWeight->"Bold"],
 ButtonBox[", 122401 (2019)",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://doi.org/10.1088/1361-6633/ab4415"], None},
  ButtonNote->"https://doi.org/10.1088/1361-6633/ab4415"],
 ", ",
 ButtonBox["HAL:02342161",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://hal.archives-ouvertes.fr/hal-02342161/"], None},
  ButtonNote->"https://hal.archives-ouvertes.fr/hal-02342161/"],
 "."
}], "Text",ExpressionUUID->"83738154-95ea-4389-b0ec-b54ceadb74f9"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Poincarana", "::", "usage"}], "=", 
    "\"\<Poincarana[E] gives the Poincarana-representation vectors \
{\!\(\*SubscriptBox[OverscriptBox[\(u\), \(\[RightArrow]\)], \
\(1\)]\),\!\(\*SubscriptBox[OverscriptBox[\(u\), \(\[RightArrow]\)], \
\(2\)]\)} for the electric-field complex amplitude \
E=\!\(\*OverscriptBox[\(E\), \
\(\[RightArrow]\)]\)={Ex,Ey,Ez}=\!\(\*SuperscriptBox[\(e\), \(\[ImaginaryI]\
\[CurlyPhi]\)]\)(\!\(\*OverscriptBox[\(A\), \
\(\[RightArrow]\)]\)+\[ImaginaryI]\!\(\*OverscriptBox[\(B\), \
\(\[RightArrow]\)]\)) (in the Jones decomposition), given by \
\!\(\*SubscriptBox[OverscriptBox[\(u\), \(\[RightArrow]\)], \(i\)]\)=\
\[PlusMinus]\!\(\*SuperscriptBox[\(f\), \(2\)]\)\!\(\*OverscriptBox[\(a\), \(\
\[RightArrow]\)]\)+\!\(\*OverscriptBox[\(S\), \(\[RightArrow]\)]\), where \
\!\(\*OverscriptBox[\(S\), \(\[RightArrow]\)]\)=Im(\!\(\*OverscriptBox[\(E\), \
\(\[RightArrow]\)]\)\[Conjugate]\[Cross]\!\(\*OverscriptBox[\(E\), \(\
\[RightArrow]\)]\))/|\!\(\*OverscriptBox[\(E\), \
\(\[RightArrow]\)]\)\!\(\*SuperscriptBox[\(|\), \(2\)]\) is the spin angular \
momentum, \!\(\*SuperscriptBox[\(f\), \(2\)]\)=|\!\(\*OverscriptBox[\(A\), \(\
\[RightArrow]\)]\)|-|\!\(\*OverscriptBox[\(B\), \(\[RightArrow]\)]\)| is the \
focal distance of the intensity-normalized ellipse, and \
\!\(\*OverscriptBox[\(a\), \(\[RightArrow]\)]\)=\!\(\*OverscriptBox[\(A\), \(\
\[RightArrow]\)]\)/|\!\(\*OverscriptBox[\(A\), \(\[RightArrow]\)]\)| is the \
normalized major-axis direction.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Poincarana", "[", "vectorE_", "]"}], ":=", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "vectorF", ",", "comp", ",", "\[Alpha]", ",", "\[Beta]", ",", "avec", 
       ",", "jvec"}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"vectorF", "=", 
       RowBox[{
        RowBox[{"-", 
         RowBox[{"Exp", "[", 
          RowBox[{
           RowBox[{"-", "I"}], " ", 
           RowBox[{"JonesPhase", "[", "vectorE", "]"}]}], "]"}]}], 
        "vectorE"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"\[Alpha]", "=", 
       RowBox[{"Chop", "[", 
        RowBox[{
         RowBox[{"vectorF", ".", "vectorF"}], "/", 
         SuperscriptBox[
          RowBox[{"Norm", "[", "vectorF", "]"}], "2"]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"\[Beta]", "=", 
       RowBox[{"Sqrt", "[", 
        RowBox[{"1", "-", 
         SuperscriptBox["\[Alpha]", "2"]}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"avec", "=", 
       RowBox[{
        RowBox[{"Re", "[", "vectorF", "]"}], "/", 
        RowBox[{"Norm", "[", 
         RowBox[{"Re", "[", "vectorF", "]"}], "]"}]}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"jvec", "=", 
       RowBox[{"If", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"Norm", "[", 
           RowBox[{"Im", "[", "vectorF", "]"}], "]"}], "\[Equal]", "0"}], ",",
          "0", ",", 
         RowBox[{"Cross", "[", 
          RowBox[{"avec", ",", 
           RowBox[{
            RowBox[{"Im", "[", "vectorF", "]"}], "/", 
            RowBox[{"Norm", "[", 
             RowBox[{"Im", "[", "vectorF", "]"}], "]"}]}]}], "]"}]}], "]"}]}],
       ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         RowBox[{"\[Alpha]", " ", "avec"}], "+", 
         RowBox[{"\[Beta]", " ", "jvec"}]}], ",", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[Alpha]"}], " ", "avec"}], "+", 
         RowBox[{"\[Beta]", " ", "jvec"}]}]}], "}"}]}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[145]:=",ExpressionUUID->"d254f39d-34f6-4ca0-84d8-83214ee749d7"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Visualization functions", \
"Subsection",ExpressionUUID->"49bc826f-9b81-4834-bd4f-f42ce17c601a"],

Cell[CellGroupData[{

Cell["UniformRadialGrid", \
"Subsubsection",ExpressionUUID->"7cb50fa9-4b5d-49b2-83cf-d4517ba000a8"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"UniformRadialGrid", "::", "usage"}], "=", 
    "\"\<UniformRadialGrid[n] produces a uniform radial grid with n rings.\n\
UniformRadialGrid[n,m] produces a uniform radial grid with n rings and m \
points on the first ring.\nUniformRadialGrid[n,m,\[CapitalDelta]r] produces a \
uniform radial grid with n rings, m points on the first ring, and spacing of \
\[CapitalDelta]r between the rings.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UniformRadialGrid", "[", 
    RowBox[{
     RowBox[{"nRings_", "?", "IntegerQ"}], ",", 
     RowBox[{"nCircle_", "?", "IntegerQ"}], ",", "\[CapitalDelta]r_"}], "]"}],
    ":=", 
   RowBox[{"Times", "[", 
    RowBox[{"\[CapitalDelta]r", ",", "\[IndentingNewLine]", 
     RowBox[{"Join", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"{", 
         RowBox[{"0", ",", "0"}], "}"}], "}"}], ",", "\[IndentingNewLine]", 
       RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Table", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"{", 
              RowBox[{
               RowBox[{"n", " ", 
                RowBox[{"Cos", "[", "\[Phi]", "]"}]}], ",", 
               RowBox[{"n", " ", 
                RowBox[{"Sin", "[", "\[Phi]", "]"}]}]}], "}"}], 
             "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"\[Phi]", ",", 
               RowBox[{"Most", "[", 
                RowBox[{"Subdivide", "[", 
                 RowBox[{"0", ",", 
                  RowBox[{"2", "\[Pi]"}], ",", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"(", 
                    RowBox[{"nCircle", "-", "1"}], ")"}], "n"}], "+", "1"}]}],
                  "]"}], "]"}]}], "}"}]}], "]"}], "\[IndentingNewLine]", ",", 
           
           RowBox[{"{", 
            RowBox[{"n", ",", "1", ",", "nRings"}], "}"}]}], "]"}], 
         "\[IndentingNewLine]", ",", "1"}], "]"}]}], "\[IndentingNewLine]", 
      "]"}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"UniformRadialGrid", "[", 
   RowBox[{
    RowBox[{"nRings_", "?", "IntegerQ"}], ",", 
    RowBox[{"nCircle_", "?", "IntegerQ"}]}], "]"}], ":=", 
  RowBox[{"UniformRadialGrid", "[", 
   RowBox[{"nRings", ",", "nCircle", ",", "1"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"UniformRadialGrid", "[", 
    RowBox[{"nRings_", "?", "IntegerQ"}], "]"}], ":=", 
   RowBox[{"UniformRadialGrid", "[", 
    RowBox[{"nRings", ",", "7", ",", "1"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->
  "In[149]:=",ExpressionUUID->"7de7f457-59cf-4799-bcb9-c03b7b7486af"],

Cell["\<\
This requires the function Subdivide, which dates from v10.1, so here is a \
fill-in substitute if running from v10.0 or earlier:\
\>", "Text",ExpressionUUID->"a556de0d-5570-422c-9766-7d9e5a7d1fa5"],

Cell[BoxData[
 RowBox[{"If", "[", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"$VersionNumber", "<", "10.1"}], ",", "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"Subdivide", "::", "usage"}], "=", 
     TagBox[
      StyleBox[
       "\"\<\\!\\(\\*RowBox[{\\\"Subdivide\\\", \\\"[\\\", \
StyleBox[\\\"n\\\", \\\"TI\\\"], \\\"]\\\"}]\\) generates the list \
\\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"0\\\", \\\",\\\", RowBox[{\\\"1\\\", \
\\\"/\\\", StyleBox[\\\"n\\\", \\\"TI\\\"]}], \\\",\\\", RowBox[{\\\"2\\\", \
\\\"/\\\", StyleBox[\\\"n\\\", \\\"TI\\\"]}], \\\",\\\", \
StyleBox[\\\"\\[Ellipsis]\\\", \\\"TR\\\"], \\\",\\\", \\\"1\\\"}], \
\\\"}\\\"}]\\).\\n\\!\\(\\*RowBox[{\\\"Subdivide\\\", \\\"[\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"max\\\", \
\\\"TI\\\"]], \\\",\\\", StyleBox[\\\"n\\\", \\\"TI\\\"]}], \\\"]\\\"}]\\) \
generates the list of values obtained by subdividing the interval 0 to \\!\\(\
\\*SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"max\\\", \\\"TI\
\\\"]]\\) into \\!\\(\\*StyleBox[\\\"n\\\", \\\"TI\\\"]\\) equal parts.\\n\\!\
\\(\\*RowBox[{\\\"Subdivide\\\", \\\"[\\\", \
RowBox[{SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\\\"min\\\", \
\\\"TI\\\"]], \\\",\\\", SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \
StyleBox[\\\"max\\\", \\\"TI\\\"]], \\\",\\\", StyleBox[\\\"n\\\", \
\\\"TI\\\"]}], \\\"]\\\"}]\\) generates the list of values from subdividing \
the interval \\!\\(\\*SubscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], StyleBox[\
\\\"min\\\", \\\"TI\\\"]]\\) to \\!\\(\\*SubscriptBox[StyleBox[\\\"x\\\", \
\\\"TI\\\"], StyleBox[\\\"max\\\", \\\"TI\\\"]]\\).\>\"",
       ShowSpecialCharacters->False,
       ShowStringCharacters->True,
       NumberMarks->True],
      FullForm]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], ";", 
    "\[IndentingNewLine]", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Subdivide", "[", 
      RowBox[{"xmin_", ",", "xmax_", ",", "n_"}], "]"}], ":=", 
     RowBox[{"xmin", "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"xmax", "-", "xmin"}], ")"}], 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0", ",", "n"}], "]"}], "/", "n"}]}]}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Subdivide", "[", 
      RowBox[{"xmax_", ",", "n_"}], "]"}], ":=", 
     RowBox[{"Subdivide", "[", 
      RowBox[{"0", ",", "xmax", ",", "n"}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Subdivide", "[", "n_", "]"}], ":=", 
     RowBox[{"Subdivide", "[", 
      RowBox[{"0", ",", "1", ",", "n"}], "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"End", "[", "]"}], ";"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[155]:=",ExpressionUUID->"19d50526-5dd0-4e9b-be71-0f0dc46643e8"]
}, Closed]],

Cell[CellGroupData[{

Cell["FieldArrow", \
"Subsubsection",ExpressionUUID->"b1a1efdf-95b0-4db4-bc66-0ee8c7c12d44"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FieldArrow", "::", "usage"}], "=", 
    "\"\<FieldArrow[kind,f,{x,y,z}] produces a field arrow associated with \
the field function f at the position (x,y,z), where the kind can be \\\"major\
\\\" (for a major-axis arrow) or \\\"spin\\\" (for the electric spin vector).\
\nFieldArrow[kind,f,{x,y,z},A] multiplies the arrow length by an amplitude A.\
\nFieldArrow[kind,f,{x,y,z},A,zoom] magnifies the position by the specified \
zoom factor.\nFieldArrow[kind,f,{x,y,z},A,zoom,{tx,ty,tz}] translates the \
position of the arrow by an offset {tx,ty,tz}.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FieldArrowheadFunction", "::", "usage"}], "=", 
   "\"\<FieldArrowheadFunction is an option for FieldArrow and \
PlotFieldArrows that specifies a function of the norm of the arrow vector \
that should output the size of arrowheads to use.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FieldArrowThicknessFunction", "::", "usage"}], "=", 
    "\"\<FieldArrowThicknessFunction is an option for FieldArrow and \
PlotFieldArrows that specifies a function of the norm of the arrow vector \
that should output the tube diameter of the arrows.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"Protect", "[", 
    RowBox[{"FieldArrowThicknessFunction", ",", "FieldArrowheadFunction"}], 
    "]"}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "FieldArrow", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"NormFunction", "\[Rule]", "Norm"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"FieldArrowThicknessFunction", "\[Rule]", "None"}], ",", 
      RowBox[{"FieldArrowheadFunction", "\[Rule]", "None"}]}], "}"}]}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FieldArrow", "[", 
   RowBox[{"kind_", ",", "fieldFunction_", ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"FieldArrow", "[", 
   RowBox[{"kind", ",", "fieldFunction", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "1", ",", "1", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "opts"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"FieldArrow", "[", 
   RowBox[{"kind_", ",", "fieldFunction_", ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], ",", "amplitude_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"FieldArrow", "[", 
   RowBox[{"kind", ",", "fieldFunction", ",", 
    RowBox[{"{", 
     RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "amplitude", ",", "1", 
    ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "opts"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FieldArrow", "[", 
    RowBox[{"kind_", ",", "fieldFunction_", ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], ",", "amplitude_", ",", 
     "zoom_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"FieldArrow", "[", 
    RowBox[{"kind", ",", "fieldFunction", ",", 
     RowBox[{"{", 
      RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "amplitude", ",", "zoom",
      ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "opts"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FieldArrow", "[", 
    RowBox[{"kind_", ",", "fieldFunction_", ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], ",", "amplitude_", ",", 
     "zoom_", ",", "translation_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "vect", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"vect", "=", 
       RowBox[{"Which", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"kind", "\[Equal]", "\"\<major\>\""}], ",", 
         RowBox[{"JonesMajorAxisA", "[", 
          RowBox[{
           RowBox[{"fieldFunction", "[", 
            RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
           RowBox[{"OptionValue", "[", "NormFunction", "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"kind", "\[Equal]", "\"\<minor\>\""}], ",", 
         RowBox[{"JonesMinorAxisB", "[", 
          RowBox[{
           RowBox[{"fieldFunction", "[", 
            RowBox[{"x", ",", "y", ",", "z"}], "]"}], ",", 
           RowBox[{"OptionValue", "[", "NormFunction", "]"}]}], "]"}], ",", 
         "\[IndentingNewLine]", 
         RowBox[{"kind", "\[Equal]", "\"\<spin\>\""}], ",", 
         RowBox[{"SpinE", "[", 
          RowBox[{"fieldFunction", "[", 
           RowBox[{"x", ",", "y", ",", "z"}], "]"}], "]"}]}], 
        "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"If", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"Not", "[", 
           RowBox[{
            RowBox[{"OptionValue", "[", "FieldArrowheadFunction", "]"}], "===",
             "None"}], "]"}], ",", "\[IndentingNewLine]", 
          RowBox[{"Arrowheads", "[", 
           RowBox[{
            RowBox[{"OptionValue", "[", "FieldArrowheadFunction", "]"}], "[", 
            
            RowBox[{"amplitude", " ", 
             RowBox[{"Norm", "[", "vect", "]"}]}], "]"}], "]"}], ",", 
          "\[IndentingNewLine]", 
          RowBox[{"{", "}"}]}], "]"}], ",", "\[IndentingNewLine]", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"ColorData", "[", 
          RowBox[{"If", "[", 
           RowBox[{
            RowBox[{"kind", "\[Equal]", "\"\<major\>\""}], ",", 
            "\"\<SolarColors\>\"", ",", "\"\<Rainbow\>\""}], "]"}], "]"}], 
         "[", 
         FractionBox[
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Re", "[", 
             RowBox[{
             "vect", "\[LeftDoubleBracket]", "3", "\[RightDoubleBracket]"}], 
             "]"}]}], "+", "1"}], 
          RowBox[{"2", 
           RowBox[{"Norm", "[", "vect", "]"}]}]], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"OptionValue", "[", "PlotStyle", "]"}], ",", 
        "\[IndentingNewLine]", "\[IndentingNewLine]", 
        RowBox[{"Arrow", "[", 
         RowBox[{"Tube", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Chop", "[", 
            RowBox[{"{", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
               RowBox[{"zoom", 
                RowBox[{"{", 
                 RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "+", 
               "translation"}], ",", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"zoom", 
                RowBox[{"{", 
                 RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "+", 
               "translation", "+", 
               RowBox[{"amplitude", "\[Times]", "vect"}]}]}], 
             "\[IndentingNewLine]", "}"}], "]"}], ",", "\[IndentingNewLine]", 
           
           RowBox[{"If", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Not", "[", 
              RowBox[{
               RowBox[{
               "OptionValue", "[", "FieldArrowThicknessFunction", "]"}], "===",
                "None"}], "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{
              "OptionValue", "[", "FieldArrowThicknessFunction", "]"}], "[", 
              RowBox[{"amplitude", " ", 
               RowBox[{"Norm", "[", "vect", "]"}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{
              RowBox[{"##", "&"}], "[", "]"}]}], "]"}]}], 
          "\[IndentingNewLine]", "]"}], "]"}]}], "\[IndentingNewLine]", 
       "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[156]:=",ExpressionUUID->"42526ef0-5e98-4039-9c36-83d13323a7f0"]
}, Closed]],

Cell[CellGroupData[{

Cell["PlotFieldArrows", \
"Subsubsection",ExpressionUUID->"f9481aca-0c54-4c7c-a2c9-e5bac03f2aa3"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"PlotFieldArrows", "::", "usage"}], "=", 
    "\"\<PlotFieldArrows[f,kind,rmax] plots a field-arrow plot (for arrows of \
the chosen kind, either \\\"major\\\" axis or \\\"spin\\\" vector) for the \
vector field function f, for radial coordinate from 0 to rmax. \n\
PlotFieldArrows[f,kind,sm,A] plots a field-arrow plot with amplitude A \
multiplying each arrow.\nPlotFieldArrows[f,kind,sm,A,zoom] plots a \
field-arrow plot with a magnification zoom on the arrow positions.\n\
PlotFieldArrows[f,kind,sm,A,zoom,{tx,ty,tz}] plots a field-arrow plot with an \
offset of {tx,ty,tz}.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "PlotFieldArrows", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"RadialPoints", "\[Rule]", "10"}], ",", 
      RowBox[{"FirstRingPoints", "\[Rule]", "4"}], ",", 
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"NormFunction", "\[Rule]", "Norm"}], ",", 
      RowBox[{"FieldArrowThicknessFunction", "\[Rule]", "None"}], ",", 
      RowBox[{"FieldArrowheadFunction", "\[Rule]", "None"}]}], "}"}]}], ";"}],
   "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PlotFieldArrows", "[", 
   RowBox[{"fieldFunction_", ",", "kind_", ",", "rmax_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"PlotFieldArrows", "[", 
   RowBox[{"fieldFunction", ",", "kind", ",", "rmax", ",", "1", ",", "1", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "opts"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PlotFieldArrows", "[", 
   RowBox[{
   "fieldFunction_", ",", "kind_", ",", "rmax_", ",", "amplitude_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"PlotFieldArrows", "[", 
   RowBox[{
   "fieldFunction", ",", "kind", ",", "rmax", ",", "amplitude", ",", "1", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "opts"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PlotFieldArrows", "[", 
    RowBox[{
    "fieldFunction_", ",", "kind_", ",", "rmax_", ",", "amplitude_", ",", 
     "zoom_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"PlotFieldArrows", "[", 
    RowBox[{
    "fieldFunction", ",", "kind", ",", "rmax", ",", "amplitude", ",", "zoom", 
     ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "opts"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PlotFieldArrows", "[", 
    RowBox[{
    "fieldFunction_", ",", "kind_", ",", "rmax_", ",", "amplitude_", ",", 
     "zoom_", ",", "translation_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Arrowheads", "[", "0.02", "]"}], ",", "\[IndentingNewLine]", 
        
        RowBox[{"Thickness", "[", "0.005", "]"}], ",", "\[IndentingNewLine]", 
        
        RowBox[{"Table", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"FieldArrow", "[", 
           RowBox[{"kind", ",", "fieldFunction", ",", 
            RowBox[{"Join", "[", 
             RowBox[{"point", ",", 
              RowBox[{"{", "0", "}"}]}], "]"}], ",", "amplitude", ",", "zoom",
             ",", "translation", ",", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"FilterRules", "[", 
              RowBox[{
               RowBox[{"{", "opts", "}"}], ",", 
               RowBox[{"Options", "[", "FieldArrow", "]"}]}], "]"}]}]}], 
           "]"}], "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"point", ",", 
            RowBox[{"UniformRadialGrid", "[", 
             RowBox[{
              RowBox[{"OptionValue", "[", "RadialPoints", "]"}], ",", 
              RowBox[{"OptionValue", "[", "FirstRingPoints", "]"}], ",", 
              RowBox[{"rmax", "/", 
               RowBox[{"OptionValue", "[", "RadialPoints", "]"}]}]}], "]"}]}],
            "}"}]}], "]"}]}], "\[IndentingNewLine]", "}"}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[167]:=",ExpressionUUID->"240f1009-43a0-4a8f-85d9-defc48aedd7d"]
}, Closed]],

Cell[CellGroupData[{

Cell["FieldEllipse", \
"Subsubsection",ExpressionUUID->"570f264a-5ca2-460c-9929-0883f362a8fb"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FieldEllipse", "::", "usage"}], "=", 
    "\"\<FieldEllipse[f,{x,y,z},a] plots the polarization ellipse of the \
vector field function f at position (x,y,z), with amplitude multiplier a.\n\
FieldEllipse[f,{x,y,z},a,normFunction] normalizes the field values by the \
maximum of normFunction over a period. The default is (1&) and is inactive; \
for unit normalization, set to Norm.\n\
FieldEllipse[f,{x,y,z},a,normFunction,zoom] magnifies the position by the \
specified zoom factor.\n\
FieldEllipse[f,{x,y,z},a,normFunction,zoom,{tx,ty,tz}] translates the \
position of the ellipse by an offset {tx,ty,tz}.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "FieldEllipse", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{"PlotPoints", "\[Rule]", 
      RowBox[{"72", "+", "1"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"FieldEllipse", "[", 
    RowBox[{"fieldFunction_", ",", 
     RowBox[{"{", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}], ",", "amplitude_", ",", 
     RowBox[{"normFunction_", ":", 
      RowBox[{"(", 
       RowBox[{"1", "&"}], ")"}]}], ",", 
     RowBox[{"zoom_", ":", "1"}], ",", 
     RowBox[{"translation_", ":", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0"}], "}"}]}], ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"field", ",", "points", ",", "norm"}], "}"}], ",", 
     "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"field", "=", 
       RowBox[{"fieldFunction", "[", 
        RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"points", "=", 
       RowBox[{"Table", "[", " ", 
        RowBox[{
         RowBox[{"Re", "[", 
          RowBox[{
           SuperscriptBox["\[ExponentialE]", 
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]t"}]], "field"}], 
          "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"\[Omega]t", ",", "0.", ",", 
           RowBox[{"360", "\[Degree]"}], ",", 
           FractionBox[
            RowBox[{"360", "\[Degree]"}], 
            RowBox[{
             RowBox[{"OptionValue", "[", "PlotPoints", "]"}], "-", "1"}]]}], 
          "}"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
      RowBox[{"norm", "=", 
       RowBox[{"Max", "[", 
        RowBox[{"normFunction", "/@", "points"}], "]"}]}], ";", 
      "\[IndentingNewLine]", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{"Polygon", "[", "\[IndentingNewLine]", 
        RowBox[{"Map", "[", 
         RowBox[{
          RowBox[{"Function", "[", 
           RowBox[{"translation", "+", 
            RowBox[{"zoom", 
             RowBox[{"{", 
              RowBox[{"x", ",", "y", ",", "0"}], "}"}]}], "+", 
            RowBox[{
             FractionBox["amplitude", "norm"], "#"}]}], "]"}], ",", 
          "points"}], "]"}], "\[IndentingNewLine]", "]"}], 
       "\[IndentingNewLine]", "}"}]}]}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[175]:=",ExpressionUUID->"f504af73-2cdd-4939-bc73-e19bbaa2f2ed"]
}, Closed]],

Cell[CellGroupData[{

Cell["PlotFieldEllipses", \
"Subsubsection",ExpressionUUID->"0fc5f976-5313-4194-83cb-b2cf9c576b7d"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"PlotFieldEllipses", "::", "usage"}], "=", 
    "\"\<PlotFieldEllipses[f,amplitude,rmax] plots a field-ellipse plot for \
the vector field function f, for radial coordinate from 0 to rmax. \n\
PlotFieldEllipses[f,amplitude,rmax,normFunction] uses the given normFunction \
to normalize the ellipses.\n\
PlotFieldEllipses[f,amplitude,rmax,normFunction,zoom] uses a magnification \
zoom on the ellipse positions.\n\
PlotFieldEllipses[f,amplitude,rmax,normFunction,zoom,{tx,ty,tz}] translates \
the ellipses by an offset {tx,ty,tz}.\>\""}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RadialPoints", "::", "usage"}], "=", 
   "\"\<RadialPoints is an option for PlotFieldArrows and PlotFieldEllipses \
that indicates how many radial points to use.\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"FirstRingPoints", "::", "usage"}], "=", 
    "\"\<FirstRingPoints is an option for PlotFieldArrows and \
PlotFieldEllipses that indicates how many points to use on the first \
ring.\>\""}], ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Begin", "[", "\"\<`Private`\>\"", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Protect", "[", "RadialPoints", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"Options", "[", "PlotFieldEllipses", "]"}], "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"PlotStyle", "\[Rule]", 
       RowBox[{"{", "}"}]}], ",", 
      RowBox[{"PlotPoints", "\[Rule]", 
       RowBox[{"72", "+", "1"}]}], ",", 
      RowBox[{"RadialPoints", "\[Rule]", "10"}], ",", 
      RowBox[{"FirstRingPoints", "\[Rule]", "4"}]}], "}"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PlotFieldEllipses", "[", 
   RowBox[{"fieldFunction_", ",", "amplitude_", ",", "rmax_", ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"PlotFieldEllipses", "[", 
   RowBox[{
   "fieldFunction", ",", "amplitude", ",", "rmax", ",", "Norm", ",", "1", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "opts"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"PlotFieldEllipses", "[", 
   RowBox[{
   "fieldFunction_", ",", "amplitude_", ",", "rmax_", ",", "normFunction_", 
    ",", 
    RowBox[{"opts", ":", 
     RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
  RowBox[{"PlotFieldEllipses", "[", 
   RowBox[{
   "fieldFunction", ",", "amplitude", ",", "rmax", ",", "normFunction", ",", 
    "1", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "opts"}], 
   "]"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PlotFieldEllipses", "[", 
    RowBox[{
    "fieldFunction_", ",", "amplitude_", ",", "rmax_", ",", "normFunction_", 
     ",", "zoom_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"PlotFieldEllipses", "[", 
    RowBox[{
    "fieldFunction", ",", "amplitude", ",", "rmax", ",", "normFunction", ",", 
     "zoom", ",", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "opts"}], "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"PlotFieldEllipses", "[", 
    RowBox[{
    "fieldFunction_", ",", "amplitude_", ",", "rmax_", ",", "normFunction_", 
     ",", "zoom_", ",", "translation_", ",", 
     RowBox[{"opts", ":", 
      RowBox[{"OptionsPattern", "[", "]"}]}]}], "]"}], ":=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"Graphics3D", "[", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"EdgeForm", "[", 
         RowBox[{"{", 
          RowBox[{"Thick", ",", "Black"}], "}"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"FaceForm", "[", 
         RowBox[{"{", 
          RowBox[{
           InterpretationBox[
            ButtonBox[
             TooltipBox[
              GraphicsBox[{
                {GrayLevel[0], RectangleBox[{0, 0}]}, 
                {GrayLevel[0], RectangleBox[{1, -1}]}, 
                {RGBColor[0.25, 0.75, 0.75], RectangleBox[{0, -1}, {2, 1}]}},
               AspectRatio->1,
               DefaultBaseStyle->"ColorSwatchGraphics",
               Frame->True,
               FrameStyle->RGBColor[0.16666666666666669`, 0.5, 0.5],
               FrameTicks->None,
               
               ImageSize->
                Dynamic[{
                 Automatic, 
                  1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                   Magnification])}],
               PlotRangePadding->None],
              "RGBColor[0.25, 0.75, 0.75]"],
             Appearance->None,
             BaseStyle->{},
             BaselinePosition->Baseline,
             ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
               If[
                Not[
                 AbsoluteCurrentValue["Deployed"]], 
                SelectionMove[Typeset`box$, All, Expression]; 
                FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                FrontEnd`Private`$ColorSelectorInitialColor = 
                 RGBColor[0.25, 0.75, 0.75]; 
                FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                MathLink`CallFrontEnd[
                  FrontEnd`AttachCell[Typeset`box$, 
                   FrontEndResource["RGBColorValueSelector"], {
                   0, {Left, Bottom}}, {Left, Top}, 
                   "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
             DefaultBaseStyle->{},
             Evaluator->Automatic,
             Method->"Preemptive"],
            RGBColor[0.25, 0.75, 0.75],
            Editable->False,
            Selectable->False], ",", 
           RowBox[{"Specularity", "[", "0", "]"}]}], "}"}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"OptionValue", "[", "PlotStyle", "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{"Table", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"FieldEllipse", "[", 
           RowBox[{"fieldFunction", ",", 
            RowBox[{"Join", "[", 
             RowBox[{"point", ",", 
              RowBox[{"{", "0", "}"}]}], "]"}], ",", "amplitude", ",", 
            "normFunction", ",", "zoom", ",", "translation", ",", 
            RowBox[{"Sequence", "@@", 
             RowBox[{"FilterRules", "[", 
              RowBox[{
               RowBox[{"{", "opts", "}"}], ",", 
               RowBox[{"Options", "[", "FieldEllipse", "]"}]}], "]"}]}]}], 
           "]"}], "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"point", ",", 
            RowBox[{"UniformRadialGrid", "[", 
             RowBox[{
              RowBox[{"OptionValue", "[", "RadialPoints", "]"}], ",", 
              RowBox[{"OptionValue", "[", "FirstRingPoints", "]"}], ",", 
              RowBox[{"rmax", "/", 
               RowBox[{"OptionValue", "[", "RadialPoints", "]"}]}]}], "]"}]}],
            "}"}]}], "]"}]}], "\[IndentingNewLine]", "}"}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"End", "[", "]"}], ";"}]}], "Input",
 InitializationCell->True,
 CellLabel->"In[180]:=",ExpressionUUID->"28850af2-7d13-46ce-802c-0ea6e18535a1"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Benchmarking", \
"Section",ExpressionUUID->"062f96a1-7e52-44d5-83b1-192cc5315d63"],

Cell[CellGroupData[{

Cell["Verifying the solutions", \
"Subsection",ExpressionUUID->"73258659-e240-4490-840e-34837284f79f"],

Cell[CellGroupData[{

Cell["The analytical expressions", \
"Subsubsection",ExpressionUUID->"998e6168-9d7c-4bb9-9d27-883c76f99284"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ComplexFocusHelicityE", "[", 
  RowBox[{"1", ",", "1", ",", "1", ",", 
   RowBox[{"{", 
    RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "q"}], 
  "]"}]], "Input",ExpressionUUID->"814d368b-cd80-4e8f-ad9e-17746c7e765f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SqrtBox[
     RowBox[{"3", " ", "\[Pi]"}]], " ", 
    RowBox[{"(", 
     RowBox[{"x", "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "3"}], " ", "\[ImaginaryI]"}], "-", 
         RowBox[{"\[ImaginaryI]", " ", "q"}], "+", "z"}], ")"}], " ", 
       RowBox[{"AnalyticalBesselJ", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", "q"}], "+", "z"}]}], 
          "}"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "\[ImaginaryI]"}], " ", 
          SuperscriptBox["q", "2"]}], "+", 
         RowBox[{"x", " ", "y"}], "+", 
         RowBox[{"2", " ", "q", " ", "z"}], "+", 
         RowBox[{"\[ImaginaryI]", " ", 
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["y", "2"], "+", 
            SuperscriptBox["z", "2"]}], ")"}]}]}], ")"}], " ", 
       RowBox[{"AnalyticalBesselJ", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", "q"}], "+", "z"}]}], 
          "}"}]}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox[
      RowBox[{"3", " ", "\[Pi]"}]]}], " ", 
    RowBox[{"(", 
     RowBox[{"x", "+", 
      RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", 
        RowBox[{"(", 
         RowBox[{"3", "+", "q", "+", 
          RowBox[{"\[ImaginaryI]", " ", "z"}]}], ")"}]}], " ", 
       RowBox[{"AnalyticalBesselJ", "[", 
        RowBox[{"2", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", "q"}], "+", "z"}]}], 
          "}"}]}], "]"}]}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"-", 
          SuperscriptBox["q", "2"]}], "+", 
         SuperscriptBox["x", "2"], "+", 
         RowBox[{"\[ImaginaryI]", " ", "x", " ", "y"}], "-", 
         RowBox[{"2", " ", "\[ImaginaryI]", " ", "q", " ", "z"}], "+", 
         SuperscriptBox["z", "2"]}], ")"}], " ", 
       RowBox[{"AnalyticalBesselJ", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", "q"}], "+", "z"}]}], 
          "}"}]}], "]"}]}]}], ")"}]}], ",", 
   RowBox[{
    RowBox[{"-", 
     SqrtBox[
      RowBox[{"3", " ", "\[Pi]"}]]}], " ", 
    SuperscriptBox[
     RowBox[{"(", 
      RowBox[{"x", "+", 
       RowBox[{"\[ImaginaryI]", " ", "y"}]}], ")"}], "2"], " ", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"AnalyticalBesselJ", "[", 
       RowBox[{"2", ",", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "\[ImaginaryI]"}], " ", "q"}], "+", "z"}]}], "}"}]}],
        "]"}], "+", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"q", "+", 
         RowBox[{"\[ImaginaryI]", " ", "z"}]}], ")"}], " ", 
       RowBox[{"AnalyticalBesselJ", "[", 
        RowBox[{"3", ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", 
           RowBox[{
            RowBox[{
             RowBox[{"-", "\[ImaginaryI]"}], " ", "q"}], "+", "z"}]}], 
          "}"}]}], "]"}]}]}], ")"}]}]}], 
  "}"}]], "Output",ExpressionUUID->"1ca4e1e3-1079-456b-84aa-e99beb5042f3"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Verifying the defining properties (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"\[Del]", "\[CenterDot]", "E"}], "=", "0"}], TraditionalForm]],
  ExpressionUUID->"42c278e3-9de7-4760-bae0-acdc61470bee"],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       SuperscriptBox["\[Del]", "2"], 
       RowBox[{"+", 
        SuperscriptBox["k", "2"]}]}], ")"}], "E"}], "=", "0"}], 
   TraditionalForm]],ExpressionUUID->"8ddd8da4-8d8c-46f3-be80-7338f321c25e"],
 ") via symbolic computation"
}], "Subsubsection",
 InitializationCell->
  True,ExpressionUUID->"0fcebac6-103c-4152-9c0f-2b8e5602b6d6"],

Cell["Divergence:", \
"Text",ExpressionUUID->"819cf895-4c37-4efc-a3eb-486140108390"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"l", "=", "0"}], ",", 
     RowBox[{"m", "=", "0"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"FullSimplify", "[", "\[IndentingNewLine]", 
    RowBox[{"Div", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ComplexFocusHelicityE", "[", 
       RowBox[{"l", ",", "m", ",", "1", ",", 
        RowBox[{"k", 
         RowBox[{"{", 
          RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], ",", "q"}], "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"81dc9fbb-d26a-4ad1-9501-cd1ace8df580"],

Cell[BoxData["0"], \
"Output",ExpressionUUID->"5d98e9c1-864f-48b9-aea4-36118bfe8880"]
}, Open  ]],

Cell["Helmholtz equation:", \
"Text",ExpressionUUID->"62f52399-ea3c-42e8-b931-2dffeddce6a7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"l", "=", "0"}], ",", 
     RowBox[{"m", "=", "0"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{"FullSimplify", "[", "\[IndentingNewLine]", 
    RowBox[{"ReplaceAll", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Plus", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"Laplacian", "[", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"ComplexFocusHelicityE", "[", 
           RowBox[{"l", ",", "m", ",", "1", ",", 
            RowBox[{"k", 
             RowBox[{"{", 
              RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], ",", "q"}], "]"}], 
          "\[IndentingNewLine]", ",", 
          RowBox[{"{", 
           RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         SuperscriptBox["k", "2"], 
         RowBox[{"ComplexFocusHelicityE", "[", 
          RowBox[{"l", ",", "m", ",", "1", ",", 
           RowBox[{"k", 
            RowBox[{"{", 
             RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], ",", "q"}], 
          "]"}]}]}], "\[IndentingNewLine]", "]"}], ",", "\[IndentingNewLine]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"AnalyticalBesselJ", "[", 
         RowBox[{"m_", ",", 
          RowBox[{"{", 
           RowBox[{"x_", ",", "y_", ",", "z_"}], "}"}]}], "]"}], 
        "\[RuleDelayed]", 
        FractionBox[
         RowBox[{"SphericalBesselJ", "[", 
          RowBox[{
           RowBox[{"Abs", "[", "m", "]"}], ",", 
           SqrtBox[
            RowBox[{
             SuperscriptBox["x", "2"], "+", 
             SuperscriptBox["y", "2"], "+", 
             SuperscriptBox["z", "2"]}]]}], "]"}], 
         SuperscriptBox[
          RowBox[{"(", 
           RowBox[{
            SuperscriptBox["x", "2"], "+", 
            SuperscriptBox["y", "2"], "+", 
            SuperscriptBox["z", "2"]}], ")"}], 
          RowBox[{
           RowBox[{"Abs", "[", "m", "]"}], "/", "2"}]]]}], "}"}]}], 
     "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", "]"}]}], 
  "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"0092dd2f-9477-4e6d-b536-041a3a8cd187"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "0", ",", "0"}], 
  "}"}]], "Output",ExpressionUUID->"90269e42-9860-46a5-b045-ba65c5dbc025"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Verifying the defining properties directly", "Subsubsection",
 InitializationCell->
  True,ExpressionUUID->"d207ca6b-8c88-438c-b5c8-ac413e579578"],

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"q", "=", "5"}], ",", "laplacian", ",", "divergence"}], "}"}], 
   ",", "\[IndentingNewLine]", 
   RowBox[{"Flatten", "[", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Table", "[", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"Join", "[", "\[IndentingNewLine]", 
          RowBox[{
           RowBox[{"Table", "[", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{
               RowBox[{"laplacian", "[", 
                RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
               RowBox[{"FullSimplify", "[", "\[IndentingNewLine]", 
                RowBox[{"Laplacian", "[", 
                 RowBox[{
                  RowBox[{
                   RowBox[{"ComplexFocusHelicityE", "[", 
                    RowBox[{"l", ",", "m", ",", "1", ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "q"}], 
                    "]"}], "\[LeftDoubleBracket]", "j", 
                   "\[RightDoubleBracket]"}], ",", 
                  RowBox[{"{", 
                   RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], 
                "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
              RowBox[{"Plot", "[", 
               RowBox[{
                RowBox[{"{", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"Re", "[", 
                   RowBox[{"laplacian", "[", 
                    RowBox[{"x", ",", "0", ",", "0"}], "]"}], "]"}], ",", 
                  RowBox[{"Re", "[", 
                   RowBox[{"-", 
                    RowBox[{
                    RowBox[{"ComplexFocusHelicityE", "[", 
                    RowBox[{"l", ",", "m", ",", "1", ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "0", ",", "0"}], "}"}], ",", "q"}], 
                    "]"}], "\[LeftDoubleBracket]", "j", 
                    "\[RightDoubleBracket]"}]}], "]"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"Im", "[", 
                   RowBox[{"laplacian", "[", 
                    RowBox[{"x", ",", "0", ",", "0"}], "]"}], "]"}], ",", 
                  RowBox[{"Im", "[", 
                   RowBox[{"-", 
                    RowBox[{
                    RowBox[{"ComplexFocusHelicityE", "[", 
                    RowBox[{"l", ",", "m", ",", "1", ",", 
                    RowBox[{"{", 
                    RowBox[{"x", ",", "0", ",", "0"}], "}"}], ",", "q"}], 
                    "]"}], "\[LeftDoubleBracket]", "j", 
                    "\[RightDoubleBracket]"}]}], "]"}]}], 
                 "\[IndentingNewLine]", "}"}], ",", 
                RowBox[{"{", 
                 RowBox[{"x", ",", "0", ",", "10"}], "}"}], 
                "\[IndentingNewLine]", ",", 
                RowBox[{"ImageSize", "\[Rule]", "250"}], 
                "\[IndentingNewLine]", ",", 
                RowBox[{"Frame", "\[Rule]", "True"}], "\[IndentingNewLine]", 
                ",", 
                RowBox[{"PlotLabel", "\[Rule]", 
                 RowBox[{"Row", "[", 
                  RowBox[{"{", 
                   RowBox[{
                   "\"\<\[ScriptL]=\>\"", ",", "l", ",", "\"\<,m=\>\"", ",", 
                    "m", ",", "\"\<, \>\"", ",", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"\"\<x\>\"", ",", "\"\<y\>\"", ",", "\"\<z\>\""}],
                     "}"}], "\[LeftDoubleBracket]", "j", 
                    "\[RightDoubleBracket]"}]}], "}"}], "]"}]}], 
                "\[IndentingNewLine]", ",", 
                RowBox[{"PlotRange", "\[Rule]", "Full"}]}], 
               "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", ",", 
             RowBox[{"{", 
              RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], "]"}], ",", 
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{
              RowBox[{"divergence", "[", 
               RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], "=", 
              RowBox[{"FullSimplify", "[", "\[IndentingNewLine]", 
               RowBox[{"Div", "[", 
                RowBox[{
                 RowBox[{"ComplexFocusHelicityE", "[", 
                  RowBox[{"l", ",", "m", ",", "1", ",", 
                   RowBox[{"{", 
                    RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "q"}], 
                  "]"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], "]"}], 
               "\[IndentingNewLine]", "]"}]}], ";", "\[IndentingNewLine]", 
             RowBox[{"Plot", "[", 
              RowBox[{
               RowBox[{"{", "\[IndentingNewLine]", 
                RowBox[{
                 RowBox[{"Re", "[", 
                  RowBox[{"divergence", "[", 
                   RowBox[{"x", ",", "0", ",", "0"}], "]"}], "]"}], ",", 
                 RowBox[{"Im", "[", 
                  RowBox[{"divergence", "[", 
                   RowBox[{"x", ",", "0", ",", "0"}], "]"}], "]"}]}], 
                "\[IndentingNewLine]", "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", "0", ",", "10"}], "}"}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"ImageSize", "\[Rule]", "250"}], "\[IndentingNewLine]",
                ",", 
               RowBox[{"Frame", "\[Rule]", "True"}], "\[IndentingNewLine]", 
               ",", 
               RowBox[{"PlotLabel", "\[Rule]", 
                RowBox[{"Row", "[", 
                 RowBox[{"{", 
                  RowBox[{
                  "\"\<\[ScriptL]=\>\"", ",", "l", ",", "\"\<,m=\>\"", ",", 
                   "m", ",", "\"\< div\>\""}], "}"}], "]"}]}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"PlotRange", "\[Rule]", "Full"}]}], 
              "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "}"}]}], 
          "]"}], "\[IndentingNewLine]", ",", 
         RowBox[{"{", 
          RowBox[{"m", ",", "0", ",", "l"}], "}"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"l", ",", "0", ",", "1"}], "}"}]}], "]"}], 
     "\[IndentingNewLine]", ",", "1"}], "]"}]}], "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"039ac73a-fca3-48d2-a9ce-4b46a2c53d67"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Intensity plots", \
"Subsection",ExpressionUUID->"d4ace885-39b8-4632-9274-d8b43c3c66ed"],

Cell[BoxData[
 RowBox[{"Block", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"R", "=", 
      RowBox[{"3", "q"}]}], ",", 
     RowBox[{"\[CapitalDelta]", "=", "0.5"}], ",", 
     RowBox[{"F0", "=", "0.075"}], ",", "g", ",", 
     RowBox[{"l", "=", "1"}], ",", 
     RowBox[{"m", "=", "l"}], ",", 
     RowBox[{"s", "=", "1"}], ",", 
     RowBox[{"k", "=", "1"}], ",", 
     RowBox[{"q", "=", "30"}]}], "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
     RowBox[{"ComplexFocusHelicityE", "[", 
      RowBox[{"l", ",", "m", ",", "s", ",", 
       RowBox[{"k", 
        RowBox[{"{", 
         RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], ",", 
       RowBox[{"k", " ", "q"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
    "\[IndentingNewLine]", 
    RowBox[{"ContourPlot", "[", "\[IndentingNewLine]", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Norm", "[", 
        RowBox[{"g", "[", 
         RowBox[{"x", ",", "0", ",", "z"}], "]"}], "]"}], "2"], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"z", ",", 
        RowBox[{"-", "R"}], ",", "R"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"x", ",", 
        RowBox[{"-", "R"}], ",", "R"}], "}"}], "\[IndentingNewLine]", ",", 
      RowBox[{"PlotRangePadding", "\[Rule]", "None"}], "\[IndentingNewLine]", 
      ",", 
      RowBox[{"ImageSize", "\[Rule]", "650"}], "\[IndentingNewLine]", ",", 
      RowBox[{"PlotPoints", "\[Rule]", "35"}], "\[IndentingNewLine]", ",", 
      RowBox[{"PlotRange", "\[Rule]", "Full"}], "\[IndentingNewLine]", ",", 
      RowBox[{"Contours", "\[Rule]", "15"}]}], "\[IndentingNewLine]", 
     "]"}]}]}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "]"}]], "Input",ExpressionUUID->"b2c96d48-38d2-49f9-8f46-9363763ababd"]
}, Closed]],

Cell[CellGroupData[{

Cell["Polarization ellipses", \
"Subsection",ExpressionUUID->"e83dc536-c8ea-4980-a00b-55ec83d21df8"],

Cell[BoxData[
 RowBox[{"DynamicModule", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"viewPoint", "=", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "2"}], "}"}]}], ",", 
     RowBox[{"viewVertical", "=", 
      RowBox[{"{", 
       RowBox[{"0", ",", "1", ",", "0"}], "}"}]}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"R", "=", 
        RowBox[{"3", 
         SqrtBox["q"]}]}], ",", 
       RowBox[{"\[CapitalDelta]", "=", 
        RowBox[{"0.5", 
         SqrtBox["q"]}]}], ",", 
       RowBox[{"F0", "=", 
        RowBox[{"0.2", 
         SqrtBox["q"]}]}], ",", "g0", ",", "g", ",", 
       RowBox[{"l", "=", "0"}], ",", 
       RowBox[{"m", "=", "0"}], ",", 
       RowBox[{"s", "=", "1"}]}], "}"}], ",", "\[IndentingNewLine]", 
     RowBox[{"SlideView", "[", "\[IndentingNewLine]", 
      RowBox[{"Table", "[", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{"g0", "=", 
          RowBox[{"Norm", "[", 
           RowBox[{"ComplexFocusHelicityE", "[", 
            RowBox[{"l", ",", "m", ",", "s", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "q"}], "]"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"g", "[", 
           RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
          RowBox[{
           FractionBox["1", "g0"], 
           RowBox[{"ComplexFocusHelicityE", "[", 
            RowBox[{"l", ",", "m", ",", "s", ",", 
             RowBox[{"{", 
              RowBox[{"x", ",", "y", ",", "z"}], "}"}], ",", "q"}], "]"}]}]}],
          ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"PlotFieldEllipses", "[", 
              RowBox[{"g", ",", "F0", ",", "R", ",", 
               RowBox[{"1", "&"}], ",", 
               RowBox[{"FirstRingPoints", "\[Rule]", "7"}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotFieldArrows", "[", 
              RowBox[{
              "g", ",", "\"\<major\>\"", ",", "R", ",", "F0", ",", "1", ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "0"}], "}"}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"FirstRingPoints", "\[Rule]", "7"}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"NormFunction", "\[Rule]", 
                RowBox[{"Function", "[", "1", "]"}]}], "\[IndentingNewLine]", 
               ",", 
               RowBox[{"PlotStyle", "\[Rule]", 
                RowBox[{"Directive", "[", "Red", "]"}]}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"FieldArrowheadFunction", "\[Rule]", 
                RowBox[{"Function", "[", 
                 RowBox[{"Min", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"0.001", "F0"}], ",", 
                    RowBox[{
                    FractionBox["F0", "25"], "#"}]}], "}"}], "]"}], "]"}]}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"FieldArrowThicknessFunction", "\[Rule]", 
                RowBox[{"Function", "[", 
                 RowBox[{"0.075", "F0"}], "]"}]}]}], "\[IndentingNewLine]", 
              "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{"PlotFieldArrows", "[", 
              RowBox[{
              "g", ",", "\"\<minor\>\"", ",", "R", ",", "F0", ",", "1", ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "0"}], "}"}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"FirstRingPoints", "\[Rule]", "7"}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"NormFunction", "\[Rule]", 
                RowBox[{"Function", "[", "1", "]"}]}], "\[IndentingNewLine]", 
               ",", 
               RowBox[{"PlotStyle", "\[Rule]", 
                RowBox[{"Directive", "[", "Blue", "]"}]}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"FieldArrowheadFunction", "\[Rule]", 
                RowBox[{"Function", "[", 
                 RowBox[{"Min", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"0.001", "F0"}], ",", 
                    RowBox[{
                    FractionBox["F0", "25"], "#"}]}], "}"}], "]"}], "]"}]}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"FieldArrowThicknessFunction", "\[Rule]", 
                RowBox[{"Function", "[", 
                 RowBox[{"0.075", "F0"}], "]"}]}]}], "\[IndentingNewLine]", 
              "]"}]}], "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]", 
           ",", 
           RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
           RowBox[{"ImageSize", "\[Rule]", "650"}], "\[IndentingNewLine]", 
           ",", 
           RowBox[{"SphericalRegion", "\[Rule]", "True"}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"Lighting", "\[Rule]", "\"\<Neutral\>\""}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"ViewPoint", "\[Rule]", 
            RowBox[{"Dynamic", "[", "viewPoint", "]"}]}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"ViewVertical", "\[Rule]", 
            RowBox[{"Dynamic", "[", "viewVertical", "]"}]}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"ViewVertical", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"PlotLabel", "\[Rule]", "q"}], "\[IndentingNewLine]", ",", 
           
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"1.1", "R", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", 
              RowBox[{"1.1", "R", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", 
              RowBox[{"\[CapitalDelta]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], "}"}]}]}], 
          "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", ",", 
        RowBox[{"{", 
         RowBox[{"q", ",", 
          RowBox[{"PowerRange", "[", 
           RowBox[{"1", ",", "100", ",", 
            SuperscriptBox["10", "0.2"]}], "]"}]}], "}"}]}], "]"}], "]"}]}], 
    "\[IndentingNewLine]", "]"}]}], "\[IndentingNewLine]", "]"}]], "Input",
 CellLabel->"In[198]:=",ExpressionUUID->"6cd30f88-6f20-4bfc-98f5-920d40602c02"]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "With varying wavenumber ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]],ExpressionUUID->
  "c35973c7-c4cb-407f-a1aa-7d81b66a0708"]
}], "Subsection",ExpressionUUID->"8aa3de49-a8e7-4d93-8944-4060e180a0b3"],

Cell[TextData[{
 "When called as ComplexFocusHelicityE[l,m,s,k {x,y,z},q], the ComplexFocus \
functions produce essentially the same plot, but at different wavelengths, so \
the plot is identical once the chosen plot points (i.e. Range[-R,R,\
\[CapitalDelta]]) are scaled appropriately.\n\nHowever, it is important to \
keep tabs on the meaning of ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]],ExpressionUUID->
  "37ec889d-f6cd-45e7-832c-d5cf4d759f5a"],
 ":\n - If used as ComplexFocusHelicityE[l,m,s,k {x,y,z},q] then the Rayleigh \
range is ",
 Cell[BoxData[
  FormBox[
   RowBox[{"q", "/", "k"}], TraditionalForm]],ExpressionUUID->
  "88236ee9-fb2b-4aaa-8837-f1f64cdf1423"],
 ".\n - If used as ComplexFocusHelicityE[l,m,s,k {x,y,z},k q] then the \
Rayleigh range is ",
 Cell[BoxData[
  FormBox["q", TraditionalForm]],ExpressionUUID->
  "bcb6991b-4d74-45da-bf3a-85f416bf89b5"],
 "."
}], "Text",ExpressionUUID->"783a507c-58b2-4571-a495-2cb71f6bd60e"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"DateString", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"DynamicModule", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"viewPoint", "=", 
      RowBox[{"{", 
       RowBox[{"1.5", ",", "0", ",", "0.2"}], "}"}]}], ",", 
     RowBox[{"viewVertical", "=", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1"}], "}"}]}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"SlideView", "[", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Block", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"R", "=", 
           RowBox[{"3", 
            RowBox[{
             SqrtBox["q"], "/", "k"}]}]}], ",", 
          RowBox[{"\[CapitalDelta]", "=", 
           RowBox[{"0.5", 
            RowBox[{
             SqrtBox["q"], "/", "k"}]}]}], ",", 
          RowBox[{"F0", "=", 
           RowBox[{"0.3", 
            RowBox[{
             SqrtBox["q"], "/", "k"}]}]}], ",", "g0", ",", "g", ",", 
          RowBox[{"l", "=", "0"}], ",", 
          RowBox[{"m", "=", "0"}], ",", 
          RowBox[{"s", "=", "1"}], ",", 
          RowBox[{"q", "=", "2"}]}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"g0", "=", 
          RowBox[{"Norm", "[", 
           RowBox[{"ComplexFocusHelicityE", "[", 
            RowBox[{"l", ",", "m", ",", "s", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "q"}], "]"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"g", "[", 
           RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
          RowBox[{
           FractionBox["1", "g0"], 
           RowBox[{"ComplexFocusHelicityE", "[", 
            RowBox[{"l", ",", "m", ",", "s", ",", 
             RowBox[{"k", " ", 
              RowBox[{"{", 
               RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], ",", "q"}], 
            "]"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"Graphics3D", "[", 
              RowBox[{"{", "\[IndentingNewLine]", 
               RowBox[{"Table", "[", 
                RowBox[{
                 RowBox[{"{", "\[IndentingNewLine]", 
                  RowBox[{
                   RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Red", ",", "Blue"}], "}"}], 
                    "\[LeftDoubleBracket]", "j", "\[RightDoubleBracket]"}], 
                   ",", "\[IndentingNewLine]", 
                   RowBox[{"Arrowheads", "[", 
                    RowBox[{"Min", "[", 
                    RowBox[{"{", 
                    RowBox[{"0.0125", ",", 
                    RowBox[{
                    FractionBox["1", "25"], 
                    RowBox[{"Norm", "[", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"F0", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Re", ",", "Im"}], "}"}], "\[LeftDoubleBracket]", 
                    "j", "\[RightDoubleBracket]"}], "[", "#", "]"}]}], "&"}], 
                    "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"x", ",", "y", ",", "0"}], "]"}], "]"}], 
                    "]"}]}]}], "}"}], "]"}], "]"}], ",", 
                   "\[IndentingNewLine]", 
                   RowBox[{"Arrow", "[", 
                    RowBox[{"Tube", "[", 
                    RowBox[{"{", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"x", ",", "y", ",", "0"}], "}"}], ",", 
                    "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"x", ",", "y", ",", "0"}], "}"}], "+", 
                    RowBox[{"F0", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"Re", ",", "Im"}], "}"}], "\[LeftDoubleBracket]", 
                    "j", "\[RightDoubleBracket]"}], "[", "#", "]"}]}]}], 
                    "&"}], "[", 
                    RowBox[{"g", "[", 
                    RowBox[{"x", ",", "y", ",", "0"}], "]"}], "]"}]}], 
                    "\[IndentingNewLine]", "}"}], "]"}], "]"}]}], 
                  "\[IndentingNewLine]", "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"j", ",", "1", ",", "2"}], "}"}], 
                 "\[IndentingNewLine]", ",", 
                 RowBox[{"{", 
                  RowBox[{"x", ",", 
                   RowBox[{"-", "R"}], ",", "R", ",", "\[CapitalDelta]"}], 
                  "}"}], ",", 
                 RowBox[{"{", 
                  RowBox[{"y", ",", 
                   RowBox[{"-", "R"}], ",", "R", ",", "\[CapitalDelta]"}], 
                  "}"}]}], "]"}], "\[IndentingNewLine]", "}"}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"Table", "[", "\[IndentingNewLine]", 
              RowBox[{
               RowBox[{"Graphics3D", "[", 
                RowBox[{"{", "\[IndentingNewLine]", 
                 RowBox[{
                  RowBox[{"EdgeForm", "[", 
                   RowBox[{"{", 
                    RowBox[{"Thick", ",", "Black"}], "}"}], "]"}], ",", 
                  "\[IndentingNewLine]", 
                  RowBox[{"FaceForm", "[", 
                   RowBox[{"{", 
                    RowBox[{
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{
                    {GrayLevel[0], RectangleBox[{0, 0}]}, 
                    {GrayLevel[0], RectangleBox[{1, -1}]}, 
                    {RGBColor[0.25, 0.75, 0.75], 
                    RectangleBox[{0, -1}, {2, 1}]}},
                    AspectRatio->1,
                    DefaultBaseStyle->"ColorSwatchGraphics",
                    Frame->True,
                    FrameStyle->RGBColor[0.16666666666666669`, 0.5, 0.5],
                    FrameTicks->None,
                    
                    ImageSize->
                    Dynamic[{
                    Automatic, 
                    1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])}],
                    PlotRangePadding->None],
                    "RGBColor[0.25, 0.75, 0.75]"],
                    Appearance->None,
                    BaseStyle->{},
                    BaselinePosition->Baseline,
                    ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.25, 0.75, 0.75]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]],
                    DefaultBaseStyle->{},
                    Evaluator->Automatic,
                    Method->"Preemptive"],
                    RGBColor[0.25, 0.75, 0.75],
                    Editable->False,
                    Selectable->False], ",", 
                    RowBox[{"Specularity", "[", "0", "]"}]}], "}"}], "]"}], 
                  ",", "\[IndentingNewLine]", 
                  RowBox[{"Polygon", "[", 
                   RowBox[{"Table", "[", "\[IndentingNewLine]", 
                    RowBox[{
                    RowBox[{
                    RowBox[{"{", 
                    RowBox[{"x", ",", "y", ",", "0"}], "}"}], "+", 
                    RowBox[{"F0", " ", 
                    RowBox[{"Re", "[", 
                    RowBox[{
                    SuperscriptBox["\[ExponentialE]", 
                    RowBox[{
                    RowBox[{"-", "\[ImaginaryI]"}], " ", "\[Omega]t"}]], 
                    RowBox[{"g", "[", 
                    RowBox[{"x", ",", "y", ",", "0"}], "]"}]}], "]"}]}]}], 
                    "\[IndentingNewLine]", ",", 
                    RowBox[{"{", 
                    RowBox[{"\[Omega]t", ",", "0.", ",", 
                    RowBox[{"360", "\[Degree]"}], ",", 
                    RowBox[{"5", "\[Degree]"}]}], "}"}]}], "]"}], "]"}]}], 
                 "\[IndentingNewLine]", "}"}], "]"}], "\[IndentingNewLine]", 
               ",", 
               RowBox[{"{", 
                RowBox[{"x", ",", 
                 RowBox[{"-", "R"}], ",", "R", ",", "\[CapitalDelta]"}], 
                "}"}], ",", 
               RowBox[{"{", 
                RowBox[{"y", ",", 
                 RowBox[{"-", "R"}], ",", "R", ",", "\[CapitalDelta]"}], 
                "}"}]}], "]"}]}], "\[IndentingNewLine]", "}"}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
           RowBox[{"ImageSize", "\[Rule]", "950"}], "\[IndentingNewLine]", 
           RowBox[{"(*", 
            RowBox[{",", 
             RowBox[{"SphericalRegion", "\[Rule]", "True"}]}], "*)"}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"Lighting", "\[Rule]", "\"\<Neutral\>\""}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"Ticks", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"Automatic", ",", "Automatic", ",", "None"}], "}"}]}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"ViewPoint", "\[Rule]", 
            RowBox[{"Dynamic", "[", "viewPoint", "]"}]}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"ViewVertical", "\[Rule]", 
            RowBox[{"Dynamic", "[", "viewVertical", "]"}]}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"PlotLabel", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"q", ",", "k"}], "}"}]}], "\[IndentingNewLine]", ",", 
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"1.05", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "R"}], ",", "R"}], "}"}]}], ",", 
              RowBox[{"1.05", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "R"}], ",", "R"}], "}"}]}], ",", 
              RowBox[{"0.05", "R", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], "}"}]}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"BoxRatios", "\[Rule]", "Automatic"}]}], 
          "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "2"}], "}"}]}], "]"}], "]"}]}], 
  "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
 RowBox[{"DateString", "[", 
  "]"}]}], "Input",ExpressionUUID->"e3391044-14a4-4da1-9cb0-099d6bb74586"],

Cell[BoxData["\<\"Mon 9 Nov 2020 15:20:54\"\>"], \
"Output",ExpressionUUID->"7d2446ff-37c2-4af5-b521-689bbd8ab7d6"],

Cell[BoxData["\<\"Mon 9 Nov 2020 15:21:14\"\>"], \
"Output",ExpressionUUID->"adad5ce6-187e-4049-b0d4-bfdbd6cc5136"]
}, Open  ]],

Cell[BoxData[{
 RowBox[{"DateString", "[", "]"}], "\[IndentingNewLine]", 
 RowBox[{"DynamicModule", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"viewPoint", "=", 
      RowBox[{"{", 
       RowBox[{"1.5", ",", "0", ",", "0.2"}], "}"}]}], ",", 
     RowBox[{"viewVertical", "=", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "1"}], "}"}]}]}], "}"}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"SlideView", "[", 
    RowBox[{"Table", "[", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"Block", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"R", "=", 
           RowBox[{"3", 
            RowBox[{
             SqrtBox["q"], "/", "k"}]}]}], ",", 
          RowBox[{"\[CapitalDelta]", "=", 
           RowBox[{"0.5", 
            RowBox[{
             SqrtBox["q"], "/", "k"}]}]}], ",", 
          RowBox[{"F0", "=", 
           RowBox[{"0.3", 
            RowBox[{
             SqrtBox["q"], "/", "k"}]}]}], ",", "g0", ",", "g", ",", 
          RowBox[{"l", "=", "0"}], ",", 
          RowBox[{"m", "=", "0"}], ",", 
          RowBox[{"s", "=", "1"}], ",", 
          RowBox[{"q", "=", "2"}]}], "}"}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"g0", "=", 
          RowBox[{"Norm", "[", 
           RowBox[{"ComplexFocusHelicityE", "[", 
            RowBox[{"l", ",", "m", ",", "s", ",", 
             RowBox[{"{", 
              RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "q"}], "]"}], 
           "]"}]}], ";", "\[IndentingNewLine]", 
         RowBox[{
          RowBox[{"g", "[", 
           RowBox[{"x_", ",", "y_", ",", "z_"}], "]"}], ":=", 
          RowBox[{
           FractionBox["1", "g0"], 
           RowBox[{"ComplexFocusHelicityE", "[", 
            RowBox[{"l", ",", "m", ",", "s", ",", 
             RowBox[{"k", " ", 
              RowBox[{"{", 
               RowBox[{"x", ",", "y", ",", "z"}], "}"}]}], ",", "q"}], 
            "]"}]}]}], ";", "\[IndentingNewLine]", "\[IndentingNewLine]", 
         RowBox[{"Show", "[", 
          RowBox[{
           RowBox[{"{", "\[IndentingNewLine]", 
            RowBox[{
             RowBox[{"PlotFieldEllipses", "[", 
              RowBox[{"g", ",", "F0", ",", "R", ",", 
               RowBox[{"1", "&"}], ",", 
               RowBox[{"FirstRingPoints", "\[Rule]", "7"}]}], "]"}], ",", 
             "\[IndentingNewLine]", 
             RowBox[{"PlotFieldArrows", "[", 
              RowBox[{
              "g", ",", "\"\<major\>\"", ",", "R", ",", "F0", ",", "1", ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "0"}], "}"}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"FirstRingPoints", "\[Rule]", "7"}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"NormFunction", "\[Rule]", 
                RowBox[{"Function", "[", "1", "]"}]}], "\[IndentingNewLine]", 
               ",", 
               RowBox[{"PlotStyle", "\[Rule]", 
                RowBox[{"Directive", "[", "Red", "]"}]}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"FieldArrowheadFunction", "\[Rule]", 
                RowBox[{"Function", "[", 
                 RowBox[{"Min", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"0.001", "F0"}], ",", 
                    RowBox[{
                    FractionBox["F0", "25"], "#"}]}], "}"}], "]"}], "]"}]}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"FieldArrowThicknessFunction", "\[Rule]", 
                RowBox[{"Function", "[", 
                 RowBox[{"0.075", "F0"}], "]"}]}]}], "\[IndentingNewLine]", 
              "]"}], ",", "\[IndentingNewLine]", 
             RowBox[{"PlotFieldArrows", "[", 
              RowBox[{
              "g", ",", "\"\<minor\>\"", ",", "R", ",", "F0", ",", "1", ",", 
               RowBox[{"{", 
                RowBox[{"0", ",", "0", ",", "0"}], "}"}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"FirstRingPoints", "\[Rule]", "7"}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"NormFunction", "\[Rule]", 
                RowBox[{"Function", "[", "1", "]"}]}], "\[IndentingNewLine]", 
               ",", 
               RowBox[{"PlotStyle", "\[Rule]", 
                RowBox[{"Directive", "[", "Blue", "]"}]}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"FieldArrowheadFunction", "\[Rule]", 
                RowBox[{"Function", "[", 
                 RowBox[{"Min", "[", 
                  RowBox[{"{", 
                   RowBox[{
                    RowBox[{"0.001", "F0"}], ",", 
                    RowBox[{
                    FractionBox["F0", "25"], "#"}]}], "}"}], "]"}], "]"}]}], 
               "\[IndentingNewLine]", ",", 
               RowBox[{"FieldArrowThicknessFunction", "\[Rule]", 
                RowBox[{"Function", "[", 
                 RowBox[{"0.075", "F0"}], "]"}]}]}], "\[IndentingNewLine]", 
              "]"}]}], "\[IndentingNewLine]", "}"}], "\[IndentingNewLine]", 
           ",", 
           RowBox[{"Axes", "\[Rule]", "True"}], "\[IndentingNewLine]", ",", 
           RowBox[{"ImageSize", "\[Rule]", "650"}], "\[IndentingNewLine]", 
           ",", 
           RowBox[{"SphericalRegion", "\[Rule]", "True"}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"Lighting", "\[Rule]", "\"\<Neutral\>\""}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"ViewPoint", "\[Rule]", 
            RowBox[{"Dynamic", "[", "viewPoint", "]"}]}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"ViewVertical", "\[Rule]", 
            RowBox[{"Dynamic", "[", "viewVertical", "]"}]}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"ViewVertical", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{"0", ",", "0", ",", "1"}], "}"}]}], 
           "\[IndentingNewLine]", ",", 
           RowBox[{"PlotLabel", "\[Rule]", "q"}], "\[IndentingNewLine]", ",", 
           
           RowBox[{"PlotRange", "\[Rule]", 
            RowBox[{"{", 
             RowBox[{
              RowBox[{"1.1", "R", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", 
              RowBox[{"1.1", "R", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "1"}], "}"}]}], ",", 
              RowBox[{"\[CapitalDelta]", 
               RowBox[{"{", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "1"}], "}"}]}]}], "}"}]}]}], 
          "\[IndentingNewLine]", "]"}]}]}], "\[IndentingNewLine]", "]"}], 
      "\[IndentingNewLine]", ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "2"}], "}"}]}], "]"}], "]"}]}], 
  "\[IndentingNewLine]", "]"}], "\[IndentingNewLine]", 
 RowBox[{"DateString", "[", "]"}]}], "Input",
 CellLabel->"In[199]:=",ExpressionUUID->"46399c4c-79fb-4909-879f-4cc54f8a15ba"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Package closure", \
"Section",ExpressionUUID->"9ef34194-5bc5-402e-b25a-b6b648543098"],

Cell[CellGroupData[{

Cell["End of package", \
"Subsubsection",ExpressionUUID->"08b5aa74-0de0-4690-976b-1c4972ab6314"],

Cell[BoxData[
 RowBox[{
  RowBox[{"EndPackage", "[", "]"}], ";"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[191]:=",ExpressionUUID->"7bfde5e2-e60e-49b0-9216-395b306e3c3c"]
}, Closed]],

Cell[CellGroupData[{

Cell["Add to distributed contexts", \
"Subsubsection",ExpressionUUID->"627f2346-484c-48d4-9453-1b9800679ff6"],

Cell[BoxData[
 RowBox[{
  RowBox[{"DistributeDefinitions", "[", "\"\<ComplexFocus`\>\"", "]"}], 
  ";"}]], "Input",
 InitializationCell->True,
 CellLabel->"In[192]:=",ExpressionUUID->"0b59eb5f-39e5-4fe3-a624-8b4b88bac2fa"]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
NotebookEventActions->{{"MenuCommand", "Save"} :> (NotebookWrite[
     Part[
      Cells[CellTags -> "version-timestamp"], 1], 
     Cell[
      BoxData[
       RowBox[{
         StringJoin["$ComplexFocusTimestamp=\"", 
          DateString[], "\";\nEnd[];"]}]], "Input", InitializationCell -> 
      True, CellTags -> "version-timestamp"], None, AutoScroll -> False]; 
   NotebookSave[]), PassEventsDown -> True},
WindowSize->{1152, 549},
WindowMargins->{{0, Automatic}, {0, Automatic}},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[{
     "Rodrigo", " ", "Guti\[EAcute]rrez", "-", "Cuevas", " ", "and", " ", 
      "Emilio", " ", "Pisanty"}], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[{
     "ComplexFocus", ":", " ", "Non", "-", "paraxial", " ", "vector", " ", 
      "beams", " ", "in", " ", "Mathematica", "|", "   ", 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}, {
   Cell[
    TextData[{
     "Rodrigo", " ", "Guti\[EAcute]rrez", "-", "Cuevas", " ", "and", " ", 
      "Emilio", " ", "Pisanty"}], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[{
     "ComplexFocus", ":", " ", "Non", "-", "paraxial", " ", "vector", " ", 
      "beams", " ", "in", " ", "Mathematica", "|", "   ", 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}},
PageFooters->{{
   Cell[
    TextData[{
     "https", ":", "//", "github", ".", "com", "/", "ComplexFocus", "/", 
      "ComplexFocus"}], "Footer", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, None}, {
   Cell[
    TextData[{
     "https", ":", "//", "github", ".", "com", "/", "ComplexFocus", "/", 
      "ComplexFocus"}], "Footer", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, None}},
PageHeaderLines->{False, False},
PageFooterLines->{False, False},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->False,
"PaperOrientation"->"Portrait",
"PaperSize"->{594.75, 842.25},
"PostScriptOutputFile"->"~/Desktop/print.pdf",
"PrintingMargins"->{{19.84251968503, 19.84251968503}, {72., 72.}}},
PrivateNotebookOptions->{"FileOutlineCache"->False},
ShowSelection->True,
TaggingRules->{
 "WelcomeScreenSettings" -> {"FEStarting" -> False}, "TryRealOnly" -> False},
TrackCellChangeTimes->False,
SpellingDictionaries->{"CorrectWords"->{
 "subpackage", "Pisanty", "subpackages"}},
Magnification:>0.75 Inherited,
Background->None,
FrontEndVersion->"12.1 for Linux x86 (64-bit) (March 18, 2020)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    StyleData["Code"], FontWeight -> "Plain", FontSlant -> "Plain", 
    FontTracking -> "Plain", 
    FontVariations -> {
     "Outline" -> False, "Shadow" -> False, "StrikeThrough" -> False, 
      "Underline" -> False}]}, Visible -> False, FrontEndVersion -> 
  "12.1 for Linux x86 (64-bit) (March 18, 2020)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"0068b283-5296-4e9a-909d-6a8830b1cd95"
]

